@@ -1,5 +1,5 @@
 /*
- * $Id: bsched.c,v 1.27 2005/05/04 17:37:20 graaff Exp $
+ * $Id: bsched.c,v 1.31 2005/06/29 17:03:00 rmanfredi Exp $
  *
  * Copyright (c) 2002-2003, Raphael Manfredi
  *
@@ -28,17 +28,20 @@
  * @file
  *
  * Bandwidth scheduling.
+ *
+ * @author Raphael Manfredi
+ * @date 2002-2003
  */
 
 #include "common.h"
 
-RCSID("$Id: bsched.c,v 1.27 2005/05/04 17:37:20 graaff Exp $");
+RCSID("$Id: bsched.c,v 1.31 2005/06/29 17:03:00 rmanfredi Exp $");
 
 #include "bsched.h"
 #include "inet.h"
 #include "uploads.h"
 
-#include "if/core/wrap.h"		/* wrapped_io_t */
+#include "if/core/wrap.h"		/* For wrapped_io_t */
 #include "if/gnet_property_priv.h"
 
 #include "lib/glib-missing.h"
@@ -59,29 +62,29 @@ static GSList *bws_in_list = NULL;
 static gint bws_out_ema = 0;
 static gint bws_in_ema = 0;
 
-#define BW_SLOT_MIN		64		/* Minimum bandwidth/slot for realloc */
+#define BW_SLOT_MIN		64		/**< Minimum bandwidth/slot for realloc */
 
-#define BW_OUT_UP_MIN	8192	/* Minimum out bandwidth for becoming ultra */
-#define BW_OUT_GNET_MIN	128		/* Minimum out bandwidth per Gnet connection */
-#define BW_OUT_LEAF_MIN	32		/* Minimum out bandwidth per leaf connection */
+#define BW_OUT_UP_MIN	8192	/**< Minimum out bandwidth for becoming ultra */
+#define BW_OUT_GNET_MIN	128		/**< Minimum out bandwidth per Gnet connection */
+#define BW_OUT_LEAF_MIN	32		/**< Minimum out bandwidth per leaf connection */
 
-#define BW_TCP_MSG		40		/* Smallest size of a TCP message */
-#define BW_UDP_MSG		20		/* Minimal IP overhead for a UDP message */
+#define BW_TCP_MSG		40		/**< Smallest size of a TCP message */
+#define BW_UDP_MSG		20		/**< Minimal IP overhead for a UDP message */
 
-#define BW_UDP_OVERSIZE	512		/* Allow that many bytes over available b/w */
+#define BW_UDP_OVERSIZE	512		/**< Allow that many bytes over available b/w */
 
 /*
  * Determine how large an I/O vector the kernel can accept.
  */
 
 #if defined(MAXIOV)
-#define MAX_IOV_COUNT	MAXIOV			/* Regular */
+#define MAX_IOV_COUNT	MAXIOV			/**< Regular */
 #elif defined(UIO_MAXIOV)
-#define MAX_IOV_COUNT	UIO_MAXIOV		/* Linux */
+#define MAX_IOV_COUNT	UIO_MAXIOV		/**< Linux */
 #elif defined(IOV_MAX)
-#define MAX_IOV_COUNT	IOV_MAX			/* Solaris */
+#define MAX_IOV_COUNT	IOV_MAX			/**< Solaris */
 #else
-#define MAX_IOV_COUNT	16				/* Unknown, use required minimum */
+#define MAX_IOV_COUNT	16				/**< Unknown, use required minimum */
 #endif
 
 /**
@@ -137,10 +140,11 @@ safe_writev(wrap_io_t *wio, struct iovec *iov, gint iovcnt)
 /**
  * Create a new bandwidth scheduler.
  *
- * `type' refers to the scheduling model.  Only BS_T_STREAM for now.
- * `mode' refers to the nature of the sources: either reading or writing.
- * `bandwidth' is the expected bandwidth in bytes per second.
- * `period' is the scheduling period in ms.
+ * @param `name' no brief description.
+ * @param `type' refers to the scheduling model.  Only BS_T_STREAM for now.
+ * @param `mode' refers to the nature of the sources: either reading or writing.
+ * @param `bandwidth' is the expected bandwidth in bytes per second.
+ * @param `period' is the scheduling period in ms.
  */
 bsched_t *
 bsched_make(gchar *name, gint type, guint32 mode, gint bandwidth, gint period)
@@ -769,7 +773,7 @@ bsched_bio_remove(bsched_t *bs, bio_source_t *bio)
  * whether the source can accept those calls without blocking will have to
  * be determined explicitly.
  *
- * Returns new bio_source object.
+ * @returns new bio_source object.
  */
 bio_source_t *
 bsched_source_add(
@@ -866,8 +870,10 @@ bsched_set_bandwidth(bsched_t *bs, gint bandwidth)
 
 
 /**
- * Returns the bandwidth available for a given source.
- * `len' is the amount of bytes requested by the application.
+ * @param `bio' no brief description.
+ * @param `len' is the amount of bytes requested by the application.
+ *
+ * @returns the bandwidth available for a given source.
  */
 static gint
 bw_available(bio_source_t *bio, gint len)
@@ -1086,8 +1092,9 @@ bw_available(bio_source_t *bio, gint len)
  * Update bandwidth used, and scheduler statistics.
  * If no more bandwidth is available, disable all sources.
  *
- * `used' is the amount of bytes used by the I/O.
- * `requested' is the amount of bytes requested for the I/O.
+ * @param `bs' no brief description.
+ * @param `used' is the amount of bytes used by the I/O.
+ * @param `requested' is the amount of bytes requested for the I/O.
  */
 static void
 bsched_bw_update(bsched_t *bs, gint used, gint requested)
@@ -1308,8 +1315,9 @@ bio_writev(bio_source_t *bio, struct iovec *iov, gint iovcnt)
 
 /**
  * Send UDP datagram to specified destination `to'.
- * If we cannot write anything due to bandwidth constraints, return -1 with
- * errno set to EAGAIN.
+ *
+ * @return -1 with errno set to EAGAIN, if we cannot write anything due
+ * to bandwidth constraints.
  */
 ssize_t
 bio_sendto(bio_source_t *bio, gnet_host_t *to, gconstpointer data, size_t len)
@@ -1390,11 +1398,12 @@ signal_handler(int n)
 
 /**
  * Write at most `len' bytes to source's fd, as bandwidth permits.
+ *
  * Bytes are read from `offset' in the in_fd file descriptor, and the value
  * is updated in place by the kernel.
  *
- * If we cannot write anything due to bandwidth constraints, return -1 with
- * errno set to EAGAIN.
+ * @return -1 with errno set to EAGAIN, if we cannot write anything due to
+ * bandwidth constraints.
  */
 ssize_t
 bio_sendfile(sendfile_ctx_t *ctx, bio_source_t *bio, gint in_fd, off_t *offset,
@@ -1585,9 +1594,11 @@ bio_sendfile(sendfile_ctx_t *ctx, bio_source_t *bio, gint in_fd, off_t *offset,
 }
 
 /**
- * Read at most `len' bytes from `buf' from source's fd, as bandwidth permits.
- * If we cannot read anything due to bandwidth constraints, return -1 with
- * errno set to EAGAIN.
+ * Read at most `len' bytes from `buf' from source's fd, as bandwidth
+ * permits.
+ *
+ * @return -1 with errno set to EAGAIN, if we cannot read anything due to
+ * bandwidth constraints.
  */
 ssize_t
 bio_read(bio_source_t *bio, gpointer data, size_t len)
@@ -1619,6 +1630,7 @@ bio_read(bio_source_t *bio, gpointer data, size_t len)
 	if (r > 0) {
 		bsched_bw_update(bio->bs, r, amount);
 		bio->bw_actual += r;
+		bio->bs->flags |= BS_F_DATA_READ;
 	}
 
 	return r;
@@ -1662,8 +1674,10 @@ bws_read(bsched_t *bs, wrap_io_t *wio, gpointer data, size_t len)
 
 	g_assert(len <= INT_MAX);
 	r = wio->read(wio, data, len);
-	if (r > 0)
+	if (r > 0) {
 		bsched_bw_update(bs, r, len);
+		bs->flags |= BS_F_DATA_READ;
+	}
 
 	return r;
 }
@@ -1677,6 +1691,7 @@ bws_udp_count_read(gint len)
 	gint count = BW_UDP_MSG + len;
 
 	bsched_bw_update(bws.gin_udp, count, count);
+	bws.gin_udp->flags |= BS_F_DATA_READ;
 }
 
 /**
@@ -1692,7 +1707,8 @@ bws_udp_count_written(gint len)
 
 /**
  * Returns adequate b/w shaper depending on the socket type.
- * Returns NULL if there is no b/w shaper to consider.
+ *
+ * @returns NULL if there is no b/w shaper to consider.
  */
 static bsched_t *
 bs_socket(enum socket_direction dir, enum socket_type type)
@@ -2089,7 +2105,7 @@ bsched_stealbeat(bsched_t *bs)
 	if (!(bs->flags & BS_F_ENABLED))	/* Scheduler disabled */
 		return;
 
-	/*
+	/**
 	 * Note that we do not use the theoric bandwidth, but bs->bw_max to
 	 * estimate the amount of underused bandwidth.  The reason is that
 	 * bs->bw_max can be corrected due to traffic spikes.
@@ -2206,6 +2222,7 @@ bsched_timer(void)
 	GSList *l;
 	gint out_used = 0;
 	gint in_used = 0;
+	gboolean read_data = FALSE;
 
 	g_get_current_time(&tv);
 
@@ -2247,7 +2264,13 @@ bsched_timer(void)
 
 	for (l = bws_in_list; l; l = g_slist_next(l)) {
 		bsched_t *bs = (bsched_t *) l->data;
+
 		in_used += (gint) (bs->bw_last_period * 1000.0 / bs->period_ema);
+
+		if (bs->flags & BS_F_DATA_READ) {
+			read_data = TRUE;
+			bs->flags &= ~BS_F_DATA_READ;
+		}
 	}
 
 	bws_in_ema += (in_used >> 6) - (bws_in_ema >> 6);		/* Slow EMA */
@@ -2255,21 +2278,31 @@ bsched_timer(void)
 	if (dbg > 4)
 		printf("Incoming b/w EMA = %d bytes/s\n", bws_in_ema);
 
-	if (in_used)
+	/*
+	 * Don't simply rely on in_used > 0 since we fake input data when
+	 * sockets are closed or timeout on connection.  We really want to know
+	 * whether there has been actual data read.
+	 *		--RAM, 2005-06-29
+	 */
+
+	if (read_data)
 		inet_read_activity();
 }
 
 /**
+ * Needs very short description so that doxygen can parse the following
+ * list properly.
+ *
  * Determine whether we have enough bandwidth to possibly become an
  * ultra node:
  *
- * 1. There must be more than BW_OUT_UP_MIN outgoing bandwidth available.
- * 2. If bandwidth schedulers are enabled, leaf nodes must not be configured
- *    to steal all the HTTP outgoing bandwidth, unless they disabled uploads.
- * 3. If Gnet out scheduler is enabled, there must be at least BW_OUT_GNET_MIN
- *    bytes per gnet connection.
- * 4. Overall, there must be BW_OUT_LEAF_MIN bytes per configured leaf plus
- *    BW_OUT_GNET_MIN bytes per gnet connection available.
+ *  -# There must be more than BW_OUT_UP_MIN outgoing bandwidth available.
+ *  -# If bandwidth schedulers are enabled, leaf nodes must not be configured
+ *     to steal all the HTTP outgoing bandwidth, unless they disabled uploads.
+ *  -# If Gnet out scheduler is enabled, there must be at least BW_OUT_GNET_MIN
+ *     bytes per gnet connection.
+ *  -# Overall, there must be BW_OUT_LEAF_MIN bytes per configured leaf plus
+ *     BW_OUT_GNET_MIN bytes per gnet connection available.
  */
 gboolean
 bsched_enough_up_bandwidth(void)
