@@ -1,5 +1,5 @@
 /*
- * $Id: gmsg.c,v 1.12 2005/05/04 17:37:22 graaff Exp $
+ * $Id: gmsg.c,v 1.15 2005/06/29 14:24:22 daichik Exp $
  *
  * Copyright (c) 2002-2003, Raphael Manfredi
  *
@@ -28,11 +28,14 @@
  * @file
  *
  * Gnutella Messages.
+ *
+ * @author Raphael Manfredi
+ * @date 2002-2003
  */
 
 #include "common.h"
 
-RCSID("$Id: gmsg.c,v 1.12 2005/05/04 17:37:22 graaff Exp $");
+RCSID("$Id: gmsg.c,v 1.15 2005/06/29 14:24:22 daichik Exp $");
 
 #include "gmsg.h"
 #include "pmsg.h"
@@ -50,10 +53,12 @@ RCSID("$Id: gmsg.c,v 1.12 2005/05/04 17:37:22 graaff Exp $");
 #include "lib/override.h"		/* Must be the last header included */
 
 static const gchar *msg_name[256];
-static gint msg_weight[256];		/* For gmsg_cmp() */
+static gint msg_weight[256];	/**< For gmsg_cmp() */
 
 /**
- * Log an hexadecimal dump of the message `data', tagged with:
+ * Log an hexadecimal dump of the message `data'.
+ *
+ * Tagged with:
  *
  *     msg_type (payload length) [hops=x, TTL=x]
  *
@@ -127,6 +132,7 @@ gmsg_name(guint function)
 
 /**
  * Construct regular PDU descriptor from message.
+ *
  * Message data is copied into the new data buffer, so caller may release
  * its memory.
  */
@@ -308,6 +314,7 @@ gmsg_sendto_one_ggep(struct gnutella_node *n,
 
 /**
  * Send control message to one node.
+ *
  * A control message is inserted ahead any other queued regular data.
  */
 void
@@ -326,6 +333,7 @@ gmsg_ctrl_sendto_one(struct gnutella_node *n, gconstpointer msg, guint32 size)
 
 /**
  * Send control message to one node.
+ *
  * A control message is inserted ahead any other queued regular data.
  */
 void
@@ -709,7 +717,7 @@ gmsg_sendto_route_ggep(
  * if it is a non-OOB query: no need to forward the request if the reply
  * will be dropped.
  *
- * Note that queries with hops=0 are not necessarily ours, since the queries
+ * @note Queries with hops=0 are not necessarily ours, since the queries
  * from our leaves are propagated as if they were coming from ourselves.
  * Therefore, unless the OOB flag is set, we always check for an existing
  * route.
@@ -785,7 +793,7 @@ gmsg_can_drop(gconstpointer pdu, gint size)
 /**
  * Perform a priority comparison between two messages, given as the whole PDU.
  *
- * Return algebraic -1/0/+1 depending on relative order.
+ * @return algebraic -1/0/+1 depending on relative order.
  */
 gint
 gmsg_cmp(gconstpointer pdu1, gconstpointer pdu2)
@@ -836,7 +844,7 @@ gmsg_cmp(gconstpointer pdu1, gconstpointer pdu2)
 }
 
 /**
- * Returns formatted static string:
+ * @returns formatted static string:
  *
  *     msg_type (payload length) [hops=x, TTL=x]
  *
@@ -873,7 +881,7 @@ gmsg_infostr_full(gconstpointer message)
 }
 
 /**
- * Returns formatted static string:
+ * @returns formatted static string:
  *
  *     msg_type (payload length) [hops=x, TTL=x]
  *
@@ -907,7 +915,7 @@ gmsg_infostr_full_split(gconstpointer head, gconstpointer data)
 }
 
 /**
- * Returns formatted static string:
+ * @returns formatted static string:
  *
  *     msg_type (payload length) [hops=x, TTL=x]
  */
