@@ -1,5 +1,5 @@
 /*
- * $Id: guid.c,v 1.5 2005/05/04 17:37:22 graaff Exp $
+ * $Id: guid.c,v 1.8 2005/06/29 14:24:22 daichik Exp $
  *
  * Copyright (c) 2002-2003, Raphael Manfredi
  *
@@ -32,11 +32,14 @@
  * HEC generation code is courtesy of Charles Michael Heard (initially
  * written for ATM, but adapted for GTKG, with leading coset leader
  * changed).
+ *
+ * @author Raphael Manfredi
+ * @date 2002-2003
  */
 
 #include "common.h"
 
-RCSID("$Id: guid.c,v 1.5 2005/05/04 17:37:22 graaff Exp $");
+RCSID("$Id: guid.c,v 1.8 2005/06/29 14:24:22 daichik Exp $");
 
 #include "guid.h"
 #include "lib/misc.h"
@@ -57,14 +60,14 @@ RCSID("$Id: guid.c,v 1.5 2005/05/04 17:37:22 graaff Exp $");
  * Flags for GUID[15] query tagging.
  */
 
-#define GUID_REQUERY		0x01	/* Cleared means initial query */
+#define GUID_REQUERY		0x01	/**< Cleared means initial query */
 
 /*
  * HEC constants.
  */
 
-#define HEC_GENERATOR	0x107		/* x^8 + x^2 + x + 1 */
-#define HEC_GTKG_MASK	0x0c3		/* HEC GTKG's mask */
+#define HEC_GENERATOR	0x107		/**< x^8 + x^2 + x + 1 */
+#define HEC_GTKG_MASK	0x0c3		/**< HEC GTKG's mask */
 
 gchar blank_guid[16] = { 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 };
 
@@ -127,7 +130,7 @@ guid_gtkg_encode_version(guint major, guint minor, gboolean rel)
 }
 
 /**
- * Compute GUID's HEC over bytes 1..15
+ * Compute GUID's HEC over bytes 1..15.
  */
 static guint8
 guid_hec(const gchar *xuid)
