@@ -1,10 +1,8 @@
 /*
- * $Id: ignore.c,v 1.8 2005/05/04 17:37:23 graaff Exp $
+ * $Id: ignore.c,v 1.11 2005/06/29 14:24:23 daichik Exp $
  *
  * Copyright (c) 2002-2003, Raphael Manfredi
  *
- * Management of download ignoring list.
- *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
  *
@@ -25,9 +23,19 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup core
+ * @file
+ *
+ * Management of download ignoring list.
+ *
+ * @author Raphael Manfredi
+ * @date 2002-2003
+ */
+
 #include "common.h"
 
-RCSID("$Id: ignore.c,v 1.8 2005/05/04 17:37:23 graaff Exp $");
+RCSID("$Id: ignore.c,v 1.11 2005/06/29 14:24:23 daichik Exp $");
 
 #include "ignore.h"
 #include "huge.h"
@@ -44,14 +52,14 @@ RCSID("$Id: ignore.c,v 1.8 2005/05/04 17:37:23 graaff Exp $");
 
 #include "lib/override.h"		/* Must be the last header included */
 
-/**
+/*
  * Hash tables where we collect SHA1 we already own or wish to ignore and
  * filename/filesizes we likewise wish to ignore.
  */
-static GHashTable *by_sha1;			/* SHA1s to ignore */
-static GHashTable *by_namesize;		/* By filename + filesize */
+static GHashTable *by_sha1;			/**< SHA1s to ignore */
+static GHashTable *by_namesize;		/**< By filename + filesize */
 
-/**
+/*
  * We expect the initial ignore_sha1 and ignore_namesize files to be in
  * the startup directory.  We'll monitor them and reload them should they
  * change during our runtime.
@@ -409,6 +417,7 @@ ignore_timer(time_t unused_now)
 
 /**
  * Remove iterator callback.
+ *
  * Free a key/value pair from the by_sha1 hash.
  */
 static gboolean
@@ -423,6 +432,7 @@ free_sha1_kv(gpointer key, gpointer unused_value, gpointer unused_udata)
 
 /**
  * Remove iterator callback.
+ *
  * Free a key/value pair from the by_namesize hash.
  */
 static gboolean
