@@ -1,5 +1,5 @@
 /*
- * $Id: ioheader.c,v 1.5 2005/05/04 17:37:23 graaff Exp $
+ * $Id: ioheader.c,v 1.8 2005/06/29 14:24:23 daichik Exp $
  *
  * Copyright (c) 2002-2003, Raphael Manfredi
  *
@@ -28,11 +28,14 @@
  * @file
  *
  * Asynchronous I/O header parsing.
+ *
+ * @author Raphael Manfredi
+ * @date 2002-2003
  */
 
 #include "common.h"
 
-RCSID("$Id: ioheader.c,v 1.5 2005/05/04 17:37:23 graaff Exp $");
+RCSID("$Id: ioheader.c,v 1.8 2005/06/29 14:24:23 daichik Exp $");
 
 #include "ioheader.h"
 #include "sockets.h"
@@ -48,23 +51,23 @@ RCSID("$Id: ioheader.c,v 1.5 2005/05/04 17:37:23 graaff Exp $");
 
 #include "lib/override.h"	/* Must be the last header included */
 
-#define DFLT_SIZE	2048	/* Expected headers should not be larger */
+#define DFLT_SIZE	2048	/**< Expected headers should not be larger */
 
-/*
+/**
  * This structure is used to encapsulate the various arguments required
  * by the header parsing I/O callbacks.
  */
 struct io_header {
-	gpointer resource;					/* Resource for which we're parsing */
-	gpointer *io_opaque;				/* Where we're referenced in resource */
-	struct gnutella_socket *socket;		/* Socket on which we're reading */
-	bsched_t *bs;						/* Bandwidth scheduler to use */
+	gpointer resource;					/**< Resource for which we're parsing */
+	gpointer *io_opaque;				/**< Where we're referenced in resource */
+	struct gnutella_socket *socket;		/**< Socket on which we're reading */
+	bsched_t *bs;						/**< Bandwidth scheduler to use */
 	header_t *header;
 	getline_t *getline;
-	const struct io_error *error;		/* Error callbacks */
-	io_done_cb_t process_header;		/* Called when all headers are read */
-	io_start_cb_t header_read_start;	/* Called when reading first byte */
-	GString *text;						/* Full header text */
+	const struct io_error *error;		/**< Error callbacks */
+	io_done_cb_t process_header;		/**< Called when all headers are read */
+	io_start_cb_t header_read_start;	/**< Called when reading first byte */
+	GString *text;						/**< Full header text */
 	gint flags;
 };
 
@@ -130,6 +133,7 @@ io_getline(gpointer opaque)
 
 /**
  * Fetch header text as C string from opaque I/O data.
+ *
  * It is up to the caller to strdup the data if needed.
  * The returned data will be freed when io_free() is called.
  */
@@ -421,14 +425,14 @@ io_read_data(gpointer data, gint unused_source, inputevt_cond_t cond)
  */
 void
 io_get_header(
-	gpointer resource,			/* Resource for which we're reading headers */
-	gpointer *io_opaque,		/* Field address in resource's structure */
-	bsched_t *bs,				/* B/w scheduler from which we read */
-	struct gnutella_socket *s,	/* Socket from which we're reading */
-	gint flags,					/* I/O parsing flags */
-	io_done_cb_t done,			/* Mandatory: final callback when all done */
-	io_start_cb_t start,		/* Optional: called when reading 1st byte */
-	const struct io_error *error) /* Mandatory: error callbacks for resource */
+	gpointer resource,			/**< Resource for which we're reading headers */
+	gpointer *io_opaque,		/**< Field address in resource's structure */
+	bsched_t *bs,				/**< B/w scheduler from which we read */
+	struct gnutella_socket *s,	/**< Socket from which we're reading */
+	gint flags,					/**< I/O parsing flags */
+	io_done_cb_t done,			/**< Mandatory: final callback when all done */
+	io_start_cb_t start,		/**< Optional: called when reading 1st byte */
+	const struct io_error *error) /**< Mandatory: error callbacks for resource */
 {
 	struct io_header *ih;
 	gint mask;
@@ -497,10 +501,10 @@ io_get_header(
  */
 void
 io_continue_header(
-	gpointer opaque,			/* Existing header parsing context */
-	gint flags,					/* New I/O parsing flags */
-	io_done_cb_t done,			/* Mandatory: final callback when all done */
-	io_start_cb_t start)		/* Optional: called when reading 1st byte */
+	gpointer opaque,			/**< Existing header parsing context */
+	gint flags,					/**< New I/O parsing flags */
+	io_done_cb_t done,			/**< Mandatory: final callback when all done */
+	io_start_cb_t start)		/**< Optional: called when reading 1st byte */
 {
 	struct io_header *ih = (struct io_header *) opaque;
 
