@@ -1,5 +1,5 @@
 /*
- * $Id: oob_proxy.c,v 1.12 2005/05/04 17:37:23 graaff Exp $
+ * $Id: oob_proxy.c,v 1.15 2005/06/29 14:24:24 daichik Exp $
  *
  * Copyright (c) 2004, Raphael Manfredi
  *
@@ -28,11 +28,14 @@
  * @file
  *
  * Proxified OOB queries.
+ *
+ * @author Raphael Manfredi
+ * @date 2004
  */
 
 #include "common.h"
 
-RCSID("$Id: oob_proxy.c,v 1.12 2005/05/04 17:37:23 graaff Exp $");
+RCSID("$Id: oob_proxy.c,v 1.15 2005/06/29 14:24:24 daichik Exp $");
 
 #include "oob_proxy.h"
 #include "share.h"
@@ -52,20 +55,20 @@ RCSID("$Id: oob_proxy.c,v 1.12 2005/05/04 17:37:23 graaff Exp $");
 #include "lib/walloc.h"
 #include "lib/override.h"		/* Must be the last header included */
 
-#define PROXY_EXPIRE_MS		(10*60*1000)	/* 10 minutes at most */
+#define PROXY_EXPIRE_MS		(10*60*1000)	/**< 10 minutes at most */
 
-/*
+/**
  * Record keeping track of the MUID remappings happening for the proxied
  * OOB queries.
  */
 struct oob_proxy_rec {
-	const gchar *leaf_muid;		/* Original MUID, set by leaf (atom) */
-	const gchar *proxied_muid;	/* Proxied MUID (atom) */
-	guint32 node_id;			/* The ID of the node leaf */
-	gpointer expire_ev;			/* Expire event, to clear this record */
+	const gchar *leaf_muid;		/**< Original MUID, set by leaf (atom) */
+	const gchar *proxied_muid;	/**< Proxied MUID (atom) */
+	guint32 node_id;			/**< The ID of the node leaf */
+	gpointer expire_ev;			/**< Expire event, to clear this record */
 };
 
-/*
+/**
  * Table recording the proxied OOB query MUID.
  */
 static GHashTable *proxied_queries = NULL;	/* New MUID => oob_proxy_rec */
@@ -204,7 +207,7 @@ oob_proxy_create(gnutella_node_t *n)
  * whether it needs results still, and claim the pending results if
  * necessary.
  *
- * @param n the remote node which has results for us
+ * @param n	the remote node which has results for us
  * @param muid the MUID of the search
  * @param hits the amount of hits available (255 mean 255+ hits).
  * @param uu_udp_firewalled the remote host is UDP-firewalled and cannot
@@ -318,8 +321,9 @@ ignore:
 
 /**
  * Called when we parsed successfully a query hit packet.
- * Look whether the MUID of hit is actually the one of an OOB-proxied query.
- * If it is, then route the hit directly to the leaf.
+ *
+ * Look whether the MUID of hit is actually the one of an OOB-proxied
+ * query. If it is, then route the hit directly to the leaf.
  *
  * @param n the node from which the message came, and where it is held
  * @param results the amount of results in the hit.
