@@ -1,5 +1,5 @@
 /*
- * $Id: settings.h,v 1.3 2005/04/27 17:06:52 cbiere Exp $
+ * $Id: settings.h,v 1.5 2005/06/25 01:37:41 daichik Exp $
  *
  * Copyright (c) 2001-2003, Raphael Manfredi, Richard Eckart
  *
@@ -23,6 +23,17 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup core
+ * @file
+ *
+ * Gtk-Gnutella configuration.
+ *
+ * @author Raphael Manfredi
+ * @author Richard Eckart
+ * @date 2001-2003
+ */
+
 #ifndef _core_settings_h_
 #define _core_settings_h_
 
@@ -30,13 +41,13 @@
 
 #include "if/core/settings.h"
 
-/*
- * Global Data
+/**
+ * Global Data.
  */
 
 extern struct in_addr *local_netmasks;
 
-/*
+/**
  * Global macros.
  */
 
@@ -53,7 +64,8 @@ void settings_shutdown(void);
 void settings_ip_changed(guint32 new_ip, guint32 peer);
 guint32 settings_max_msg_size(void);
 void settings_close(void);
-void settings_ask_for_property(gchar *name, gchar *value) G_GNUC_NORETURN;
+void settings_ask_for_property(const gchar *name,
+	const gchar *value) G_GNUC_NORETURN;
 
 guint32 get_average_servent_uptime(time_t now);
 guint32 get_average_ip_lifetime(time_t now);
