@@ -1,5 +1,5 @@
 /*
- * $Id: tsync.c,v 1.12 2005/05/04 17:37:24 graaff Exp $
+ * $Id: tsync.c,v 1.14 2005/06/25 01:37:41 daichik Exp $
  *
  * Copyright (c) 2004, Raphael Manfredi
  *
@@ -28,11 +28,14 @@
  * @file
  *
  * Time synchronization between two peers.
+ *
+ * @author Raphael Manfredi
+ * @date 2004
  */
 
 #include "common.h"
 
-RCSID("$Id: tsync.c,v 1.12 2005/05/04 17:37:24 graaff Exp $");
+RCSID("$Id: tsync.c,v 1.14 2005/06/25 01:37:41 daichik Exp $");
 
 #include "nodes.h"
 #include "tsync.h"
@@ -46,28 +49,28 @@ RCSID("$Id: tsync.c,v 1.12 2005/05/04 17:37:24 graaff Exp $");
 #include "lib/walloc.h"
 #include "lib/override.h"	/* Must be the last header included */
 
-#define TSYNC_EXPIRE_MS		(60*1000)	/* Expiration time: 60 secs */
+#define TSYNC_EXPIRE_MS		(60*1000)	/**< Expiration time: 60 secs */
 
 typedef enum {
 	TSYNC_MAGIC = 0x781f372f
 } tsync_magic_t;
 
-/*
+/**
  * Records the time at which we sent a "Time Sync" to remote peers,
  * along with the event that will expire those entries.
  */
 struct tsync {
-	tsync_magic_t magic;	/* Magic of this structure for consistency checks */
-	tm_t sent;				/* Time at which we sent the synchronization */
-	guint32 node_id;		/* Node to which we sent the request */
-	gpointer expire_ev;		/* Expiration callout queue callback */
-	gboolean udp;			/* Whether request was sent using UDP */
+	tsync_magic_t magic;	/**< Magic of this structure for consistency checks */
+	tm_t sent;				/**< Time at which we sent the synchronization */
+	guint32 node_id;		/**< Node to which we sent the request */
+	gpointer expire_ev;		/**< Expiration callout queue callback */
+	gboolean udp;			/**< Whether request was sent using UDP */
 };
 
 /*
  * Table recording the "tsync" structures, indexed by sent time.
  */
-static GHashTable *tsync_by_time = NULL;	/* tm_t -> tsync */
+static GHashTable *tsync_by_time = NULL;	/**< tm_t -> tsync */
 
 /**
  * Free a tsync structure.
