@@ -1,12 +1,8 @@
 /*
- * $Id: tx_dgram.c,v 1.12 2005/05/16 05:05:39 cbiere Exp $
+ * $Id: tx_dgram.c,v 1.14 2005/06/29 14:24:25 daichik Exp $
  *
  * Copyright (c) 2002-2003, Raphael Manfredi
  *
- * Network driver -- datagram level.
- *
- * This driver sends datagrams to specified hosts.
- *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
  *
@@ -27,9 +23,21 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup core
+ * @file
+ *
+ * Network driver -- datagram level.
+ *
+ * This driver sends datagrams to specified hosts.
+ *
+ * @author Raphael Manfredi
+ * @date 2002-2003
+ */
+
 #include "common.h"
 
-RCSID("$Id: tx_dgram.c,v 1.12 2005/05/16 05:05:39 cbiere Exp $");
+RCSID("$Id: tx_dgram.c,v 1.14 2005/06/29 14:24:25 daichik Exp $");
 
 #include "sockets.h"
 #include "nodes.h"
@@ -48,8 +56,8 @@ RCSID("$Id: tx_dgram.c,v 1.12 2005/05/16 05:05:39 cbiere Exp $");
  * Private attributes for the layer.
  */
 struct attr {
-	wrap_io_t 	 *wio;	/* Cached wrapped IO object */
-	bio_source_t *bio;	/* Bandwidth-limited I/O source */
+	wrap_io_t 	 *wio;	/**< Cached wrapped IO object */
+	bio_source_t *bio;	/**< Bandwidth-limited I/O source */
 };
 
 /**
@@ -85,6 +93,7 @@ is_writable(gpointer data, gint unused_source, inputevt_cond_t cond)
 
 /**
  * Initialize the driver.
+ *
  * Always succeeds, so never returns NULL.
  */
 static gpointer
@@ -196,7 +205,8 @@ tx_dgram_write_error(txdrv_t *tx, gnet_host_t *to, const char *func)
 
 /**
  * Send buffer datagram to specified destination `to'.
- * Returns amount of bytes written, or -1 on error with errno set.
+ *
+ * @returns amount of bytes written, or -1 on error with errno set.
  */
 static ssize_t
 tx_dgram_sendto(txdrv_t *tx, gnet_host_t *to, gpointer data, size_t len)
@@ -273,16 +283,16 @@ tx_dgram_bio_source(txdrv_t *tx)
 }
 
 static const struct txdrv_ops tx_dgram_ops = {
-	tx_dgram_init,			/* init */
-	tx_dgram_destroy,		/* destroy */
-	tx_no_write,			/* write */
-	tx_no_writev,			/* writev */
-	tx_dgram_sendto,		/* sendto */
-	tx_dgram_enable,		/* enable */
-	tx_dgram_disable,		/* disable */
-	tx_dgram_pending,		/* pending */
-	tx_dgram_flush,			/* flush */
-	tx_dgram_bio_source,	/* bio_source */
+	tx_dgram_init,			/**< init */
+	tx_dgram_destroy,		/**< destroy */
+	tx_no_write,			/**< write */
+	tx_no_writev,			/**< writev */
+	tx_dgram_sendto,		/**< sendto */
+	tx_dgram_enable,		/**< enable */
+	tx_dgram_disable,		/**< disable */
+	tx_dgram_pending,		/**< pending */
+	tx_dgram_flush,			/**< flush */
+	tx_dgram_bio_source,	/**< bio_source */
 };
 
 const struct txdrv_ops *
