@@ -1,5 +1,5 @@
 /*
- * $Id: vmsg.c,v 1.40 2005/05/16 05:13:05 cbiere Exp $
+ * $Id: vmsg.c,v 1.43 2005/07/03 11:56:31 cbiere Exp $
  *
  * Copyright (c) 2003, Raphael Manfredi
  *
@@ -28,11 +28,14 @@
  * @file
  *
  * Vendor-specific messages.
+ *
+ * @author Raphael Manfredi
+ * @date 2003
  */
 
 #include "common.h"
 
-RCSID("$Id: vmsg.c,v 1.40 2005/05/16 05:13:05 cbiere Exp $");
+RCSID("$Id: vmsg.c,v 1.43 2005/07/03 11:56:31 cbiere Exp $");
 
 #include "vmsg.h"
 #include "nodes.h"
@@ -61,7 +64,7 @@ RCSID("$Id: vmsg.c,v 1.40 2005/05/16 05:13:05 cbiere Exp $");
 #include "lib/vendors.h"
 #include "lib/override.h"	/* Must be the last header included */
 
-static gchar v_tmp[4128];	/* Large enough for a payload of 4K */
+static gchar v_tmp[4128];	/**< Large enough for a payload of 4K */
 
 /*
  * Vendor message handler.
@@ -72,8 +75,8 @@ struct vmsg;
 typedef void (*vmsg_handler_t)(struct gnutella_node *n,
 	const struct vmsg *vmsg, gchar *payload, gint size);
 
-/*
- * Definition of vendor messages
+/**
+ * Definition of vendor messages.
  */
 struct vmsg {
 	guint32 vendor;
@@ -114,7 +117,7 @@ static void handle_time_sync_reply(struct gnutella_node *n,
 static void handle_udp_crawler_ping(struct gnutella_node *n,
 	const struct vmsg *vmsg, gchar *payload, gint size);
 
-/*
+/**
  * Known vendor-specific messages.
  */
 static const struct vmsg vmsg_map[] = {
@@ -143,7 +146,7 @@ static const struct vmsg vmsg_map[] = {
 	/* Above line intentionally left blank (for "!}sort" in vi) */
 };
 
-/*
+/**
  * Items in the "Messages Supported" vector.
  */
 struct vms_item {
@@ -152,9 +155,9 @@ struct vms_item {
 	guint16 version;
 };
 
-#define VMS_ITEM_SIZE		8		/* Each entry is 8 bytes (4+2+2) */
+#define VMS_ITEM_SIZE		8		/**< Each entry is 8 bytes (4+2+2) */
 
-/*
+/**
  * Items in the "Features Supported" vector.
  */
 struct vms_feature {
@@ -162,7 +165,7 @@ struct vms_feature {
 	guint16 version;
 };
 
-#define VMS_FEATURE_SIZE	6		/* Each entry is 6 bytes (4+2) */
+#define VMS_FEATURE_SIZE	6		/**< Each entry is 6 bytes (4+2) */
 
 #define PAIR_CMP(x, y, a0, a1, b0, b1) \
 ( \
@@ -176,7 +179,7 @@ struct vms_feature {
 /**
  * Find message, given vendor code, and id, version.
  *
- * Returns handler callback if found, NULL otherwise.
+ * @returns handler callback if found, NULL otherwise.
  */
 static const struct vmsg *
 find_message(guint32 vendor, guint16 id, guint16 version)
@@ -184,7 +187,11 @@ find_message(guint32 vendor, guint16 id, guint16 version)
   gint c_vendor, c_id, c_version;
 
 #define GET_KEY(i) (&vmsg_map[(i)])
-#define FOUND(i) do { return &vmsg_map[(i)]; } while (0)
+#define FOUND(i) G_STMT_START { \
+	return &vmsg_map[(i)];		\
+	/* NOTREACHED */ 			\
+} G_STMT_END
+
 #define COMPARE(item, key) \
 	0 != (c_vendor = VENDOR_CODE_CMP((item)->key, key)) \
 		? c_vendor \
@@ -292,7 +299,7 @@ vmsg_handle(struct gnutella_node *n)
  * `size' is only the size of the payload we filled so far.
  * `maxsize' is the size of the already allocated vendor messsage.
  *
- * Returns the total size of the whole Gnutella message.
+ * @returns the total size of the whole Gnutella message.
  */
 static guint32
 vmsg_fill_header(struct gnutella_header *header, guint32 size, guint32 maxsize)
@@ -321,7 +328,7 @@ vmsg_fill_header(struct gnutella_header *header, guint32 size, guint32 maxsize)
  * Fill leading part of the payload data, containing the common part for
  * all vendor-specific messages.
  *
- * Returns start of payload after that common part.
+ * @returns start of payload after that common part.
  */
 static gchar *
 vmsg_fill_type(
@@ -635,7 +642,7 @@ vmsg_send_tcp_connect_back(struct gnutella_node *n, guint16 port)
 }
 
 /**
- * Handle the "UDP Connect Back" message.
+ * Handle the \"UDP Connect Back" message.
  */
 static void
 handle_udp_connect_back(struct gnutella_node *n,
