@@ -1,5 +1,5 @@
 /*
- * $Id: aging.c,v 1.4 2004/12/09 04:28:08 cbiere Exp $
+ * $Id: aging.c,v 1.7 2005/06/29 14:24:26 daichik Exp $
  *
  * Copyright (c) 2004, Raphael Manfredi
  *
@@ -24,15 +24,19 @@
  */
 
 /**
+ * @ingroup lib
  * @file
  *
  * Hash table with aging values, removed automatically after
  * some time has elapsed.
+ *
+ * @author Raphael Manfredi
+ * @date 2004
  */
 
 #include "common.h"
 
-RCSID("$Id: aging.c,v 1.4 2004/12/09 04:28:08 cbiere Exp $");
+RCSID("$Id: aging.c,v 1.7 2005/06/29 14:24:26 daichik Exp $");
 
 #include "aging.h"
 #include "cq.h"
@@ -40,7 +44,7 @@ RCSID("$Id: aging.c,v 1.4 2004/12/09 04:28:08 cbiere Exp $");
 #include "walloc.h"
 #include "override.h"		/* Must be the last header included */
 
-/*
+/**
  * The hash table is the central piece, but we also have a `value freeing'
  * callback, since the values can expire automatically.
  */
@@ -48,26 +52,26 @@ RCSID("$Id: aging.c,v 1.4 2004/12/09 04:28:08 cbiere Exp $");
 #define AGING_MAGIC	0xa9179
 
 struct aging {
-	guint32 magic;			/* Magic number */
-	GHashTable *table;		/* The table holding values */
-	aging_free_t kfree;		/* The freeing callback for keys */
-	aging_free_t vfree;		/* The freeing callback for values */
-	gpointer kdata;			/* User data to give to key-freeing callback */
-	gpointer vdata;			/* User data to give to value-freeing callback */
-	gint delay;				/* Initial aging delay, in seconds */
+	guint32 magic;			/**< Magic number */
+	GHashTable *table;		/**< The table holding values */
+	aging_free_t kfree;		/**< The freeing callback for keys */
+	aging_free_t vfree;		/**< The freeing callback for values */
+	gpointer kdata;			/**< User data to give to key-freeing callback */
+	gpointer vdata;			/**< User data to give to value-freeing callback */
+	gint delay;				/**< Initial aging delay, in seconds */
 };
 
-/*
+/**
  * We wrap the values we insert in the table, since each value must keep
  * track of its insertion time, and cleanup event.
  */
 struct aging_value {
-	gpointer value;			/* The value they inserted in the table */
-	gpointer key;			/* The associated key object */
-	gpointer cq_ev;			/* Scheduled cleanup event */
-	struct aging *ag;		/* Holding container */
-	gint ttl;				/* Time to live */
-	time_t last_insert;		/* Last insertion time */
+	gpointer value;			/**< The value they inserted in the table */
+	gpointer key;			/**< The associated key object */
+	gpointer cq_ev;			/**< Scheduled cleanup event */
+	struct aging *ag;		/**< Holding container */
+	gint ttl;				/**< Time to live */
+	time_t last_insert;		/**< Last insertion time */
 };
 
 /**
@@ -200,6 +204,7 @@ aging_remove(gpointer obj, gpointer key)
 
 /**
  * Add value to the table.
+ *
  * If it was already present, its lifetime is augmented by the aging delay.
  *
  * The key argument is freed immediately if there is a free routine for
