@@ -1,10 +1,8 @@
 /*
- * $Id: header.c,v 1.5 2005/03/25 04:45:42 cbiere Exp $
+ * $Id: header.c,v 1.7 2005/06/29 14:24:26 daichik Exp $
  *
  * Copyright (c) 2001-2003, Raphael Manfredi
  *
- * Header parsing routines.
- *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
  *
@@ -25,9 +23,19 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup lib
+ * @file
+ *
+ * Header parsing routines.
+ *
+ * @author Raphael Manfredi
+ * @date 2001-2003
+ */
+
 #include "common.h"
 
-RCSID("$Id: header.c,v 1.5 2005/03/25 04:45:42 cbiere Exp $");
+RCSID("$Id: header.c,v 1.7 2005/06/29 14:24:26 daichik Exp $");
 
 #include "header.h"
 #include "glib-missing.h"
@@ -40,23 +48,23 @@ RCSID("$Id: header.c,v 1.5 2005/03/25 04:45:42 cbiere Exp $");
  *** Operating flags
  ***/
 
-#define HEAD_F_EOH		0x00000001			/* EOH reached */
-#define HEAD_F_SKIP		0x00000002			/* Skip continuations */
+#define HEAD_F_EOH		0x00000001			/**< EOH reached */
+#define HEAD_F_SKIP		0x00000002			/**< Skip continuations */
 
 /***
  *** Error code management
  ***/
 
 static const char *error_str[] = {
-	"OK",									/* HEAD_OK */
-	"Unexpected continuation line",			/* HEAD_CONTINUATION */
-	"Malformed header line",				/* HEAD_MALFORMED */
-	"Invalid characters in field name",		/* HEAD_BAD_CHARS */
-	"End of header already reached",		/* HEAD_EOH_REACHED */
-	"Skipped continuation line",			/* HEAD_SKIPPED */
-	"Header too large",						/* HEAD_TOO_LARGE */
-	"Header has too many lines",			/* HEAD_MANY_LINES */
-	"End of header",						/* HEAD_EOH */
+	"OK",									/**< HEAD_OK */
+	"Unexpected continuation line",			/**< HEAD_CONTINUATION */
+	"Malformed header line",				/**< HEAD_MALFORMED */
+	"Invalid characters in field name",		/**< HEAD_BAD_CHARS */
+	"End of header already reached",		/**< HEAD_EOH_REACHED */
+	"Skipped continuation line",			/**< HEAD_SKIPPED */
+	"Header too large",						/**< HEAD_TOO_LARGE */
+	"Header has too many lines",			/**< HEAD_MANY_LINES */
+	"End of header",						/**< HEAD_EOH */
 };
 
 /**
@@ -124,7 +132,7 @@ hfield_make(const gchar *name)
 	return h;
 }
 
-/*
+/**
  * hfield_free
  *
  * Dispose of the header field.
@@ -519,23 +527,23 @@ header_dump(const header_t *o, FILE *out)
  ***/
 
 #define HEADER_FMT_MAGIC		0xf7a91c
-#define HEADER_FMT_DFLT_LEN		256		/* Default field length if no hint */
-#define HEADER_FMT_LINE_LEN		78		/* Try to never emit longer lines */
-#define HEADER_FMT_MAX_SIZE		1024	/* Max line size for header */
+#define HEADER_FMT_DFLT_LEN		256		/**< Default field length if no hint */
+#define HEADER_FMT_LINE_LEN		78		/**< Try to never emit longer lines */
+#define HEADER_FMT_MAX_SIZE		1024	/**< Max line size for header */
 
-/*
- * Header formatting context
+/**
+ * Header formatting context.
  */
 struct header_fmt {
 	guint32 magic;
-	gint maxlen;				/* Maximum line length before continuation */
-	GString *header;			/* Header being built */
-	gchar sep[257];				/* Optional separator */
-	gint seplen;				/* Length of separator string */
-	gint stripped_seplen;		/* Length of separator without trailing space */
-	gint current_len;			/* Length of currently built line */
-	gboolean data_emitted;		/* Whether data was ever emitted */
-	gboolean frozen;			/* Header terminated */
+	gint maxlen;				/**< Maximum line length before continuation */
+	GString *header;			/**< Header being built */
+	gchar sep[257];				/**< Optional separator */
+	gint seplen;				/**< Length of separator string */
+	gint stripped_seplen;		/**< Length of separator without trailing space */
+	gint current_len;			/**< Length of currently built line */
+	gboolean data_emitted;		/**< Whether data was ever emitted */
+	gboolean frozen;			/**< Header terminated */
 };
 
 /**
@@ -561,23 +569,24 @@ stripped_strlen(const gchar *s, gint len)
 	return 0;
 }
 
-/*
+/**
  * header_fmt_make
  *
  * Create a new formatting context for a header line.
  *
- * `field' is the header field name, without trailing ':'.
+ * @param `field' is the header field name, without trailing ':'.
  *
- * `separator' is the optional default separator to emit between the values
- * added via header_fmd_append_value().  To supersede the default separator,
- * use header_fmd_append() and specify another separator explicitly.  If
- * set to NULL, there will be no default separator and values will be simply
- * concatenated together.  The value given must NOT be freed before
- * the header_fmt_end() call (usually it will just be a static string).
- * Trailing spaces in the separator will be stripped if it is emitted at
- * the end of a line before a continuation.
+ * @param `separator' is the optional default separator to emit between
+ * the values added via header_fmd_append_value().  To supersede the
+ * default separator, use header_fmd_append() and specify another separator
+ * explicitly.  If set to NULL, there will be no default separator and
+ * values will be simply concatenated together.  The value given must
+ * NOT be freed before the header_fmt_end() call (usually it will just
+ * be a static string).  Trailing spaces in the separator will be stripped
+ * if it is emitted at the end of a line before a continuation.
  *
- * `len_hint' is the expected line size, for pre-sizing purposes. (0 to guess).
+ * @param `len_hint' is the expected line size, for pre-sizing purposes.
+ * (0 to guess).
  *
  * @return opaque pointer.
  */
@@ -640,6 +649,7 @@ header_fmt_free(gpointer o)
  * within the `maxlen' total header size requirement in case a continuation
  * is emitted, and using the configured separator.
  *
+ * @attention
  * NB: The `maxlen' parameter is the amount of data that can be generated for
  * the header string, not counting the final "\r\n" + the trailing NUL byte.
  */
@@ -668,10 +678,13 @@ header_fmt_value_fits(gpointer o, gint len, gint maxlen)
 /**
  * Append data `str' to the header line, atomically.
  *
- * `separator' is an optional separator string that will be emitted BEFORE
- * outputting the data, and only when nothing has been emitted already.
- * `slen' is the separator length, 0 if empty.
- * `sslen' is the stripped separator length, -1 if unknown yet.
+ * @param `hf' no brief description.
+ * @param `str' no brief description.
+ * @param `separator' is an optional separator string that will be emitted
+ *         BEFORE outputting the data, and only when nothing has been emitted
+ *         already.
+ * @param `slen' is the separator length, 0 if empty.
+ * @param `sslen' is the stripped separator length, -1 if unknown yet.
  */
 static void
 header_fmt_append_full(struct header_fmt *hf, const gchar *str,
@@ -753,7 +766,7 @@ header_fmt_append_value(gpointer o, const gchar *str)
 }
 
 /**
- * Returns length of currently formatted header.
+ * @return length of currently formatted header.
  */
 gint
 header_fmt_length(gpointer o)
@@ -796,6 +809,8 @@ header_fmt_string(gpointer o)
 
 /**
  * Convert current header to a string.
+ *
+ * @attention
  * NB: returns pointer to static data!
  */
 gchar *
