@@ -1,5 +1,5 @@
 /*
- * $Id: misc.c,v 1.43 2005/05/04 01:29:24 cbiere Exp $
+ * $Id: misc.c,v 1.49 2005/07/01 14:17:44 daichik Exp $
  *
  * Copyright (c) 2001-2003, Raphael Manfredi
  *
@@ -24,17 +24,21 @@
  */
 
 /**
+ * @ingroup lib
  * @file
  *
- * Misc functions.
+ * Miscellaneous functions.
+ *
+ * @author Raphael Manfredi
+ * @date 2001-2003
  */
 
 #include "common.h"
 
-RCSID("$Id: misc.c,v 1.43 2005/05/04 01:29:24 cbiere Exp $");
+RCSID("$Id: misc.c,v 1.49 2005/07/01 14:17:44 daichik Exp $");
 
-#include <netdb.h>			/* For gethostbyname() */
-#include <sys/times.h>		/* For times() */
+#include <netdb.h>				/* For gethostbyname() */
+#include <sys/times.h>			/* For times() */
 
 #include "base32.h"
 #include "misc.h"
@@ -95,6 +99,7 @@ strlcpy(gchar *dst, const gchar *src, size_t dst_size)
  * @param dst the destination buffer.
  * @param size the number of bytes ``dst'' can hold.
  * @param s the first source string or NULL.
+ *
  * @return the sum of the lengths of all passed strings.
  */
 size_t
@@ -141,6 +146,7 @@ concat_strings(gchar *dst, size_t size, const gchar *s, ...)
  *
  * @param str a NUL-terminated string
  * @param prefix a NUL-terminated string
+ *
  * @return	NULL, if ``prefix'' is not a prefix of ``str''. Otherwise, a
  *			pointer to the first character in ``str'' after the prefix.
  */
@@ -168,6 +174,7 @@ is_strprefix(const gchar *str, const gchar *prefix)
  *
  * @param str a NUL-terminated string
  * @param prefix a NUL-terminated string
+ *
  * @return	NULL, if ``prefix'' is not a prefix of ``str''. Otherwise, a
  *			pointer to the first character in ``str'' after the prefix.
  */
@@ -190,8 +197,9 @@ is_strcaseprefix(const gchar *str, const gchar *prefix)
 }
 
 /**
- * Checks whether the given string contains a valid IP address. If the
- * string is NULL returns FALSE.
+ * Checks whether the given string contains a valid IP address.
+ *
+ * @return FALSE if the string is NULL.
  */
 gboolean
 is_string_ip(const gchar *s)
@@ -316,8 +324,9 @@ gchar_to_ip(const gchar *str)
  * A strict string to IP address conversion; when other stuff from misc.[ch]
  * is not sufficient.
  *
- * Returns TRUE if ``s'' pointed to a string representation of an IPv4
+ * @return TRUE if ``s'' pointed to a string representation of an IPv4
  * address, otherwise FALSE.
+ *
  * If successful, ``*addr'' will be set to the IPv4 address in NATIVE
  * byte order and ``*endptr'' will point to the character after the
  * IPv4 address. ``addr'' and ``endptr'' may be NULL.
@@ -365,7 +374,8 @@ gchar_to_ip_strict(const gchar *s, guint32 *addr, gchar const **endptr)
 
 /**
  * Decompiles ip:port into ip and port.  Leading spaces are ignored.
- * Returns TRUE if it parsed correctly, FALSE otherwise.
+ *
+ * @return TRUE if it parsed correctly, FALSE otherwise.
  */
 gboolean
 gchar_to_ip_port(const gchar *str, guint32 *ip, guint16 *port)
@@ -476,7 +486,7 @@ host_to_ip(const gchar *host)
 }
 
 /**
- * Returns local host name, as pointer to static data.
+ * @returns local host name, as pointer to static data.
  */
 gchar *
 host_name(void)
@@ -519,7 +529,7 @@ ip_is_valid(guint32 ip)
  * Remove final char of string if it is a "\n" or "\r".
  * If len is 0, compute it.
  *
- * Returns new string length.
+ * @returns new string length.
  */
 gint
 str_chomp(gchar *str, gint len)
@@ -543,7 +553,9 @@ str_chomp(gchar *str, gint len)
 }
 
 /**
- * Checks for RFC1918 private addresses; returns TRUE if is a private address.
+ * Checks for RFC1918 private addresses.
+ *
+ * @return TRUE if is a private address.
  */
 gboolean
 is_private_ip(guint32 ip)
@@ -568,7 +580,7 @@ is_private_ip(guint32 ip)
 }
 
 /**
- * Check whether path is an absolute path
+ * Check whether path is an absolute path.
  */
 gboolean
 is_absolute_path(const char *path)
@@ -578,7 +590,7 @@ is_absolute_path(const char *path)
 }
 
 /**
- * Check whether path is a directory
+ * Check whether path is a directory.
  */
 gboolean
 is_directory(const gchar *path)
@@ -590,7 +602,7 @@ is_directory(const gchar *path)
 }
 
 /**
- * Check whether path points to a regular file
+ * Check whether path points to a regular file.
  */
 gboolean
 is_regular(const gchar *path)
@@ -602,7 +614,7 @@ is_regular(const gchar *path)
 }
 
 /**
- * Check whether path is a symbolic link
+ * Check whether path is a symbolic link.
  */
 gboolean
 is_symlink(const gchar *path)
@@ -620,9 +632,9 @@ short_size(guint64 size)
 
 	if (size < 1024) {
 		if (size == 1)
-			gm_snprintf(b, sizeof(b), "1 Byte");
+			gm_snprintf(b, sizeof(b), _("1 Byte"));
 		else
-			gm_snprintf(b, sizeof(b), "%u Bytes", (guint) size);
+			gm_snprintf(b, sizeof(b), _("%u Bytes"), (guint) size);
 	} else if (size < 1048576)
 		gm_snprintf(b, sizeof(b), "%.2f KiB", (gfloat) size / 1024.0);
 	else if (size < 1073741824)
@@ -743,7 +755,8 @@ compact_rate(guint64 rate)
 	static gchar buf[64];
 	gchar ratebuf[48];
 
-	gm_snprintf(buf, sizeof buf, "%sB/s",
+	/* TRANSLATORS: Don't translate 'B', just 's' is allowed. */
+	gm_snprintf(buf, sizeof buf, _("%sB/s"),
 		compact_value(ratebuf, sizeof ratebuf, rate));
 	return buf;
 }
@@ -754,7 +767,8 @@ short_rate(guint64 rate)
 	static gchar buf[64];
 	gchar ratebuf[48];
 
-	gm_snprintf(buf, sizeof buf, "%sB/s",
+	/* TRANSLATORS: Don't translate 'B', just 's' is allowed. */
+	gm_snprintf(buf, sizeof buf, _("%sB/s"),
 		short_value(ratebuf, sizeof ratebuf, rate));
 	return buf;
 }
@@ -790,7 +804,7 @@ compact_kb_size(guint32 size)
 }
 
 /**
- * Return time spent in seconds in a consise short readable form
+ * @return time spent in seconds in a consise short readable form
  */
 gchar *
 short_time(gint t)
@@ -832,7 +846,7 @@ short_uptime(gint uptime)
 }
 
 /**
- * Returns hexadecimal string representing given GUID.
+ * @return hexadecimal string representing given GUID.
  */
 gchar *
 guid_hex_str(const gchar *guid)
@@ -851,7 +865,9 @@ guid_hex_str(const gchar *guid)
 }
 
 /**
- * Returns hexadecimal string representation of "small" binary buffer.
+ * @return hexadecimal string representation of "small" binary buffer.
+ *
+ * @note
  * Buffer must be less than 40 chars, or only the first 40 chars are
  * represented with a trailing "..." added to show it is incomplete.
  */
@@ -911,7 +927,8 @@ hex2dec(guchar c)
 
 /**
  * Converts hexadecimal string into a GUID.
- * Returns true if OK.
+ *
+ * @return true if OK.
  */
 gboolean
 hex_to_guid(const gchar *hexguid, gchar *guid)
@@ -933,7 +950,8 @@ hex_to_guid(const gchar *hexguid, gchar *guid)
 
 /**
  * Converts GUID into its base32 representation, without the trailing padding.
- * Returns pointer to static data.
+ *
+ * @return pointer to static data.
  */
 gchar *
 guid_base32_str(const gchar *guid)
@@ -947,7 +965,8 @@ guid_base32_str(const gchar *guid)
 
 /**
  * Decode the base32 representation of a GUID.
- * Returns pointer to static data, or NULL if the input was not valid base32.
+ *
+ * @return pointer to static data, or NULL if the input was not valid base32.
  */
 gchar *
 base32_to_guid(const gchar *base32)
@@ -965,7 +984,8 @@ base32_to_guid(const gchar *base32)
 
 /**
  * Convert binary SHA1 into a base32 string.
- * Returns pointer to static data.
+ *
+ * @return pointer to static data.
  */
 gchar *
 sha1_base32(const gchar *sha1)
@@ -982,6 +1002,7 @@ sha1_base32(const gchar *sha1)
  * Convert base32 string into binary SHA1.
  *
  * @param base32 a buffer holding SHA1_BASE32_SIZE or more bytes.
+ *
  * @return	Returns pointer to static data or NULL if the input wasn't a
  *			validly base32 encoded SHA1.
  */
@@ -999,7 +1020,8 @@ base32_sha1(const gchar *base32)
 
 /**
  * Convert time to ISO style date, e.g. "2002-06-09T14:54:42Z".
- * Returns pointer to static data.
+ *
+ * @return pointer to static data.
  */
 gchar *
 date_to_iso_gchar(time_t date)
@@ -1105,7 +1127,8 @@ date_to_rfc822(time_t date, gchar *buf, gint len)
 
 /**
  * Convert time to RFC-822 style date.
- * Returns pointer to static data.
+ *
+ * @return pointer to static data.
  */
 gchar *
 date_to_rfc822_gchar(time_t date)
@@ -1146,7 +1169,8 @@ date_to_rfc1123(time_t date, gchar *buf, gint len)
 
 /**
  * Convert time to RFC-1123 style date.
- * Returns pointer to static data.
+ *
+ * @returns pointer to static data.
  */
 gchar *
 date_to_rfc1123_gchar(time_t date)
@@ -1158,7 +1182,7 @@ date_to_rfc1123_gchar(time_t date)
 }
 
 /**
- * Returns the closest power of two greater or equal to `n'.
+ * @returns the closest power of two greater or equal to `n'.
  * next_pow2(0) and next_pow2(0x8.......) return 0.
  */
 guint32
@@ -1200,6 +1224,7 @@ highest_bit_set(guint32 n)
  * @param val The value to force within the range.
  * @param min The minimum value which val can be.
  * @param max The maximum value with val can be.
+ *
  * @return The new value of val which will be between
  *         min and max.
  */
@@ -1215,7 +1240,7 @@ force_range(gfloat val, gfloat min, gfloat max)
 }
 
 /**
- * Return random value between (0..max).
+ * @return random value between (0..max).
  */
 guint32
 random_value(guint32 max)
@@ -1665,7 +1690,7 @@ guid_random_fill(gchar *xuid)
  * Determine unique filename for `file' in `path', with optional trailing
  * extension `ext'.  If no `ext' is wanted, one must supply an empty string.
  *
- * Returns the chosen unique complete filename as a pointer which must be
+ * @returns the chosen unique complete filename as a pointer which must be
  * freed.
  */
 gchar *
@@ -1753,7 +1778,8 @@ unique_filename(const gchar *path, const gchar *file, const gchar *ext)
 
 /**
  * Escape all non-printable chars into the hexadecimal "\xhh" form.
- * Returns new escaped string, or the original string if no escaping occurred.
+ *
+ * @returns new escaped string, or the original string if no escaping occurred.
  */
 gchar *
 hex_escape(const gchar *name, gboolean strict)
@@ -1790,7 +1816,8 @@ hex_escape(const gchar *name, gboolean strict)
 
 /**
  * Extracts the IP address into `ip' and the netmask into `netmask'.
- * Returns whether the supplied string represents a valid ip/mask combination.
+ *
+ * @returns whether the supplied string represents a valid ip/mask combination.
  *
  * Accepted forms:
  * "a.b.c.d"			implies /32
@@ -1914,7 +1941,8 @@ make_pathname(const gchar *dir, const gchar *file)
 
 /**
  * Determine stripped down path, removing SRC_PREFIX if present.
- * Returns pointer within supplied string.
+ *
+ * @returns pointer within supplied string.
  */
 gchar *
 short_filename(gchar *fullname)
@@ -2243,7 +2271,7 @@ parse_major_minor(const gchar *src, gchar const **endptr,
 }
 
 /**
- * Find amount of common leading bits between two IP addresses
+ * Find amount of common leading bits between two IP addresses.
  */
 static guint8
 find_common_leading(guint32 ip1, guint32 ip2)
@@ -2360,9 +2388,11 @@ ip_range_split(
  *
  * @param signo the signal number.
  * @param handler the signal handler to install.
+ *
  * @return the previous signal handler or SIG_ERR on failure.
  *
- * TODO: Add Configure check for SA_INTERRUPT
+ * @todo
+ * TODO: Add Configure check for SA_INTERRUPT.
  *
  */
 signal_handler_t
