@@ -1,5 +1,5 @@
 /*
- * $Id: vendors.c,v 1.7 2005/04/24 19:11:32 cbiere Exp $
+ * $Id: vendors.c,v 1.9 2005/06/29 14:24:27 daichik Exp $
  *
  * Copyright (c) 2001-2003, Richard Eckart
  *
@@ -23,9 +23,19 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup lib
+ * @file
+ *
+ * Vendor code management.
+ *
+ * @author Richard Eckart
+ * @date 2001-2003
+ */
+
 #include "common.h"
 
-RCSID("$Id: vendors.c,v 1.7 2005/04/24 19:11:32 cbiere Exp $");
+RCSID("$Id: vendors.c,v 1.9 2005/06/29 14:24:27 daichik Exp $");
 
 #include "vendors.h"
 #include "endian.h"
@@ -114,7 +124,8 @@ struct vendor {
 
 /**
  * Find vendor name, given vendor code.
- * Returns vendor string if found, NULL otherwise.
+ *
+ * @returns vendor string if found, NULL otherwise.
  */
 static gchar *
 find_vendor(guchar raw[4])
@@ -138,7 +149,7 @@ find_vendor(guchar raw[4])
 }
 
 /**
- * Return true is gtk-gnutella knows the given 4-byte vendor code.
+ * @return true is gtk-gnutella knows the given 4-byte vendor code.
  */
 gboolean
 is_vendor_known(guchar raw[4])
@@ -151,7 +162,8 @@ is_vendor_known(guchar raw[4])
 
 /**
  * Make up a printable version of the vendor code.
- * Returns pointer to static data.
+ *
+ * @return pointer to static data.
  */
 gchar *
 vendor_code_str(guint32 code)
