@@ -1,10 +1,8 @@
 /*
- * $Id: walloc.c,v 1.3 2004/12/09 04:28:08 cbiere Exp $
+ * $Id: walloc.c,v 1.6 2005/06/29 14:24:27 daichik Exp $
  *
  * Copyright (c) 2002-2003, Raphael Manfredi
  *
- * Explicit-width block allocator, based on zalloc().
- *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
  *
@@ -25,9 +23,19 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup lib
+ * @file
+ *
+ * Explicit-width block allocator, based on zalloc().
+ *
+ * @author Raphael Manfredi
+ * @date 2002-2003
+ */
+
 #include "common.h"
 
-RCSID("$Id: walloc.c,v 1.3 2004/12/09 04:28:08 cbiere Exp $");
+RCSID("$Id: walloc.c,v 1.6 2005/06/29 14:24:27 daichik Exp $");
 
 #include "walloc.h"
 #include "zalloc.h"
@@ -44,14 +52,14 @@ RCSID("$Id: walloc.c,v 1.3 2004/12/09 04:28:08 cbiere Exp $");
 #endif
 
 #ifdef TRACK_ZALLOC
-#undef walloc					/* We want to define the real routines */
+#undef walloc				/* We want to define the real routines */
 #undef walloc0
 #undef wrealloc
 #endif
 
-#define WALLOC_MAX		4096	/* Passed this size, use malloc() */
-#define WALLOC_CHUNK	4096	/* Target chunk size for small structs */
-#define WALLOC_MINCOUNT	8		/* Minimum amount of structs in a chunk */
+#define WALLOC_MAX		4096	/**< Passed this size, use malloc() */
+#define WALLOC_CHUNK	4096	/**< Target chunk size for small structs */
+#define WALLOC_MINCOUNT	8		/**< Minimum amount of structs in a chunk */
 
 #define WZONE_SIZE	(WALLOC_MAX / ZALLOC_ALIGNBYTES)
 
@@ -62,7 +70,7 @@ static struct zone *wzone[WZONE_SIZE];
  */
 
 #ifndef REMAP_ZALLOC
-/*
+/**
  * walloc
  *
  * Allocate memory from a zone suitable for the given size.
@@ -72,7 +80,7 @@ static struct zone *wzone[WZONE_SIZE];
  * and to malloc() if size is greater or equal to WALLOC_MAX.
  * Naturally, zones are allocated on demand only.
  *
- * Returns a pointer to the start of the allocated block.
+ * @return a pointer to the start of the allocated block.
  */
 gpointer walloc(int size)
 {
@@ -110,7 +118,7 @@ gpointer walloc(int size)
 	return zalloc(zone);
 }
 
-/*
+/**
  * walloc0
  *
  * Same as walloc(), but zeroes the allocated memory before returning.
@@ -125,7 +133,7 @@ gpointer walloc0(int size)
 	return p;
 }
 
-/*
+/**
  * wfree
  *
  * Free a block allocated via walloc().
@@ -157,11 +165,12 @@ void wfree(gpointer ptr, gint size)
 	zfree(zone, ptr);
 }
 
-/*
+/**
  * wrealloc
  *
  * Reallocate a block allocated via walloc().
- * Returns new block address.
+ *
+ * @return new block address.
  */
 gpointer wrealloc(gpointer old, gint old_size, gint new_size)
 {
@@ -184,11 +193,12 @@ gpointer wrealloc(gpointer old, gint old_size, gint new_size)
  ***/
 
 #ifdef TRACK_ZALLOC
-/*
+/**
  * walloc_track
  *
  * Allocate memory from a zone suitable for the given size.
- * Returns a pointer to the start of the allocated block.
+ *
+ * @returns a pointer to the start of the allocated block.
  */
 gpointer walloc_track(int size, gchar *file, gint line)
 {
@@ -230,7 +240,7 @@ gpointer walloc_track(int size, gchar *file, gint line)
 	return zalloc_track(zone, file, line);
 }
 
-/*
+/**
  * walloc0_track
  *
  * Same as walloc_track(), but zeroes the allocated memory before returning.
@@ -245,11 +255,12 @@ gpointer walloc0_track(int size, gchar *file, gint line)
 	return p;
 }
 
-/*
+/**
  * wrealloc_track
  *
  * Reallocate a block allocated via walloc().
- * Returns new block address.
+ *
+ * @return new block address.
  */
 gpointer wrealloc_track(gpointer old, gint old_size, gint new_size,
 	gchar *file, gint line)
@@ -268,7 +279,7 @@ gpointer wrealloc_track(gpointer old, gint old_size, gint new_size,
 }
 #endif	/* TRACK_ZALLOC */
 
-/*
+/**
  * wdestroy
  *
  * Destroy all the zones we allocated so far.
