@@ -1,10 +1,8 @@
 /*
- * $Id: gtk-missing.c,v 1.20 2005/05/04 01:29:24 cbiere Exp $
+ * $Id: gtk-missing.c,v 1.22 2005/06/29 14:24:28 daichik Exp $
  *
  * Copyright (c) 2002-2003, Richard Eckart
  *
- * Functions that should be in gtk+-1.2 or gtk+-2.x but are not.
- *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
  *
@@ -25,9 +23,21 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup gtk
+ * @file
+ *
+ * Missing functions in the GTK+.
+ *
+ * Functions that should be in GTK+ 1.2 or GTK+ 2.x but are not.
+ *
+ * @author Richard Eckart
+ * @date 2002-2003
+ */
+
 #include "gui.h"
 
-RCSID("$Id: gtk-missing.c,v 1.20 2005/05/04 01:29:24 cbiere Exp $");
+RCSID("$Id: gtk-missing.c,v 1.22 2005/06/29 14:24:28 daichik Exp $");
 
 #include "gtk-missing.h"
 #include "columns.h"
@@ -40,8 +50,8 @@ RCSID("$Id: gtk-missing.c,v 1.20 2005/05/04 01:29:24 cbiere Exp $");
 #include "lib/walloc.h"
 #include "lib/override.h"		/* Must be the last header included */
 
-/*
- * gtk_paned_get_position:
+/**
+ * @fn gtk_paned_get_position(GtkPaned *paned)
  *
  * Get position of divider in a GtkPaned. (in GTK2)
  */
@@ -61,7 +71,8 @@ gtk_paned_get_position(GtkPaned *paned)
  * Set the internal name of the column without changing the
  * column header widget. (Copy paste internal column_title_new
  * from gtkclist.c)
- * BEWARE: EVIL HACK
+ *
+ * @warning EVIL HACK
  */
 void
 gtk_clist_set_column_name(GtkCList * clist, gint col, gchar * t)
@@ -113,11 +124,10 @@ gtk_clist_restore_visibility(GtkCList *clist, property_t prop)
 #endif /* USE_GTK1 */
 
 
-/*
- * gtk_main_flush:
+/**
+ * Process all pending gtk events (id est draw now!).
  *
- * Process all pending gtk events (i.e. draw now!)
- * Returns TRUE if gtk_main_quit has been called
+ * @returns TRUE if gtk_main_quit has been called
  * for the innermost mainloop. Aborts flush if
  * gtk_main_quit has been called.
  */
@@ -210,7 +220,8 @@ option_menu_get_selected_data(GtkWidget *m)
 /**
  * Given a radio button it returns a pointer to the active radio
  * button in the group the given button is in.
- * Returns NULL if there is no active button.
+ *
+ * @returns NULL if there is no active button.
  */
 GtkWidget *
 radiobutton_get_active_in_group(GtkRadioButton *rb)
