@@ -1,5 +1,5 @@
 /*
- * $Id: hcache.c,v 1.4 2004/12/09 06:34:47 cbiere Exp $
+ * $Id: hcache.c,v 1.5 2005/06/25 01:37:44 daichik Exp $
  *
  * Copyright (c) 2001-2003, Richard Eckart
  *
@@ -25,7 +25,7 @@
 
 #include "gtk/gui.h"
 
-RCSID("$Id: hcache.c,v 1.4 2004/12/09 06:34:47 cbiere Exp $");
+RCSID("$Id: hcache.c,v 1.5 2005/06/25 01:37:44 daichik Exp $");
 
 #include "gtk/hcache.h"
 #include "gtk/notebooks.h"
@@ -54,7 +54,7 @@ void on_clist_hcache_resize_column(
 
     lock = TRUE;
 
-    /* remember the width for storing it to the config file later */
+    /** remember the width for storing it to the config file later */
     gui_prop_set_guint32(PROP_HCACHE_COL_WIDTHS, &buf, column, 1);
 
     lock = FALSE;
