@@ -1,10 +1,8 @@
 /*
- * $Id: fileinfo.c,v 1.24 2005/05/04 01:29:25 cbiere Exp $
+ * $Id: fileinfo.c,v 1.28 2005/07/26 21:20:16 cbiere Exp $
  *
  * Copyright (c) 2003, Richard Eckart
  *
- * Displaying of file information in the gui.
- *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
  *
@@ -25,9 +23,19 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup gtk
+ * @file
+ *
+ * Displaying of file information in the GUI.
+ *
+ * @author Richard Eckart
+ * @date 2003
+ */
+
 #include "gtk/gui.h"
 
-RCSID("$Id: fileinfo.c,v 1.24 2005/05/04 01:29:25 cbiere Exp $");
+RCSID("$Id: fileinfo.c,v 1.28 2005/07/26 21:20:16 cbiere Exp $");
 
 #include "gtk/filter.h"
 #include "gtk/visual_progress.h"
@@ -83,7 +91,7 @@ fi_gui_update_row(GtkTreeStore *store, GtkTreeIter *iter, gchar **titles)
 {
 	if (NULL != titles[c_fi_filename]) {
 		gtk_tree_store_set(store, iter,
-			c_fi_filename, lazy_locale_to_utf8(titles[c_fi_filename], 0),
+			c_fi_filename, lazy_locale_to_utf8(titles[c_fi_filename]),
 			(-1));
 	}
 	gtk_tree_store_set(store, iter,
@@ -94,6 +102,7 @@ fi_gui_update_row(GtkTreeStore *store, GtkTreeIter *iter, gchar **titles)
 		c_fi_isize, *(guint64 *) titles[c_fi_isize],
 		c_fi_idone, GPOINTER_TO_UINT(titles[c_fi_idone]),
 		c_fi_isources, GPOINTER_TO_UINT(titles[c_fi_isources]),
+		c_fi_istatus, GPOINTER_TO_UINT(titles[c_fi_istatus]),
 		(-1));
 }
 
@@ -114,7 +123,7 @@ fi_gui_set_details(gnet_fi_t fih)
     aliases = guc_fi_get_aliases(fih);
 
     gtk_entry_set_text(entry_fi_filename,
-		lazy_locale_to_utf8(fi->file_name, 0));
+		lazy_locale_to_utf8(fi->file_name));
 	uint64_to_string_buf(bytes, sizeof bytes, fis.size);
     gtk_label_printf(label_fi_size, _("%s (%s bytes)"),
 		short_size(fis.size), bytes);
@@ -126,7 +135,7 @@ fi_gui_set_details(gnet_fi_t fih)
 	for (i = 0; NULL != aliases[i]; i++) {
 		gtk_tree_store_append(store_aliases, &iter, NULL);
 		gtk_tree_store_set(store_aliases, &iter, 0,
-			lazy_locale_to_utf8(aliases[i], 0), (-1));
+			lazy_locale_to_utf8(aliases[i]), (-1));
 	}
     g_strfreev(aliases);
     guc_fi_free_info(fi);
@@ -260,7 +269,7 @@ fi_gui_fill_status(gnet_fi_t fih, gchar *titles[c_fi_num])
     static gchar fi_done[SIZE_FIELD_MAX+10];
     static gchar fi_size[SIZE_FIELD_MAX];
     static guint64 isize;
-	guint idone;
+	guint idone, idone_percent;
 
     guc_fi_get_status(fih, &s);
 
@@ -276,31 +285,38 @@ fi_gui_fill_status(gnet_fi_t fih, gchar *titles[c_fi_num])
             short_size(s.done), done);
         titles[c_fi_done] = fi_done;
 		idone = done * ((1 << 30) / 101);
+		idone_percent = done;
     } else {
         titles[c_fi_done] = "-";
 		idone = 0;
+		idone_percent = 0;
     }
 
     g_strlcpy(fi_size, short_size(s.size), sizeof(fi_size));
 	titles[c_fi_size]  = fi_size;
 	isize = s.size;
-    titles[c_fi_isize] = (gpointer) &isize;
+    titles[c_fi_isize] = cast_to_gpointer(&isize);
     titles[c_fi_idone] = GUINT_TO_POINTER(idone);
 
     if (s.recvcount) {
+		titles[c_fi_istatus] = GUINT_TO_POINTER(3 * 100 + idone_percent);
 		gm_snprintf(fi_status, sizeof(fi_status),
             _("Downloading (%s)"), short_rate(s.recv_last_rate));
         titles[c_fi_status] = fi_status;
     } else if (s.done == s.size) {
+		titles[c_fi_istatus] = GUINT_TO_POINTER(4 * 100 + idone_percent);
         titles[c_fi_status] = _("Finished");
     } else if (s.lifecount == 0) {
+		titles[c_fi_istatus] = GUINT_TO_POINTER(0 * 100 + idone_percent);
         titles[c_fi_status] = _("No sources");
     } else if (s.aqueued_count || s.pqueued_count) {
+		titles[c_fi_istatus] = GUINT_TO_POINTER(2 * 100 + idone_percent);
         gm_snprintf(fi_status, sizeof(fi_status),
             _("Queued (%d active, %d passive)"),
             s.aqueued_count, s.pqueued_count);
         titles[c_fi_status] = fi_status;
     } else {
+		titles[c_fi_istatus] = GUINT_TO_POINTER(1 * 100 + idone_percent);
         titles[c_fi_status] = _("Waiting");
     }
     titles[c_fi_handle] = GUINT_TO_POINTER(fih);
@@ -544,18 +560,19 @@ fi_gui_init(void)
     	{ c_fi_size,	 N_("Size"),	1.0, compare_uint64_func, c_fi_isize },
     	{ c_fi_done,	 N_("Done"),	1.0, compare_uint_func, c_fi_idone },
     	{ c_fi_sources,  N_("Sources"), 1.0, compare_uint_func, c_fi_isources },
-    	{ c_fi_status,   N_("Status"),	0.0, NULL, -1 }
+    	{ c_fi_status,   N_("Status"),	0.0, compare_uint_func, c_fi_istatus }
 	};
 	static GType types[] = {
-		G_TYPE_STRING,	/* Filename */
-		G_TYPE_STRING,	/* Size		*/
-		G_TYPE_STRING,	/* Done		*/
-		G_TYPE_STRING,	/* Sources	*/
-		G_TYPE_STRING,	/* Status	*/
+		G_TYPE_STRING,	/* Filename				*/
+		G_TYPE_STRING,	/* Size					*/
+		G_TYPE_STRING,	/* Done					*/
+		G_TYPE_STRING,	/* Sources				*/
+		G_TYPE_STRING,	/* Status				*/
 		G_TYPE_UINT,	/* Fileinfo handle		*/
 		G_TYPE_UINT64,	/* Size (for sorting)	*/
 		G_TYPE_UINT,	/* Done (for sorting)	*/
-		G_TYPE_UINT		/* Sources (for sorting */
+		G_TYPE_UINT,	/* Sources (for sorting) */
+		G_TYPE_UINT		/* Status (for sorting) */
 	};
     static const GtkTargetEntry targets[] = {
         { "STRING", 0, 23 },
