@@ -1,10 +1,8 @@
 /*
- * $Id: nodes.c,v 1.33 2005/05/04 01:29:25 cbiere Exp $
+ * $Id: nodes.c,v 1.36 2005/07/26 21:20:16 cbiere Exp $
  *
  * Copyright (c) 2001-2003, Raphael Manfredi, Richard Eckart
  *
- * GUI filtering functions.
- *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
  *
@@ -25,9 +23,20 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup gtk
+ * @file
+ *
+ * GUI filtering functions.
+ *
+ * @author Raphael Manfredi
+ * @author Richard Eckart
+ * @date 2001-2003
+ */
+
 #include "gtk/gui.h"
 
-RCSID("$Id: nodes.c,v 1.33 2005/05/04 01:29:25 cbiere Exp $");
+RCSID("$Id: nodes.c,v 1.36 2005/07/26 21:20:16 cbiere Exp $");
 
 #include "interface-glade.h"
 
@@ -46,9 +55,9 @@ RCSID("$Id: nodes.c,v 1.33 2005/05/04 01:29:25 cbiere Exp $");
 #include "lib/utf8.h"
 #include "lib/glib-missing.h"
 #include "lib/iso3166.h"
-#include "lib/override.h"		/* Must be the last header included */
+#include "lib/override.h"	/* Must be the last header included */
 
-#define UPDATE_MIN	300		/* Update screen every 5 minutes at least */
+#define UPDATE_MIN	300		/**< Update screen every 5 minutes at least */
 
 /*
  * These hash tables record which information about which nodes has
@@ -79,7 +88,7 @@ static void nodes_gui_node_added(gnet_node_t);
 static void nodes_gui_node_info_changed(gnet_node_t);
 static void nodes_gui_node_flags_changed(gnet_node_t);
 
-/*
+/**
  * add_column
  *
  * Create a column, associating the attribute ``attr'' (usually "text") of the
@@ -240,7 +249,8 @@ nodes_gui_update_node_info(gnet_node_info_t *n, GtkTreeIter *iter)
 		n->proto_major, n->proto_minor);
 
 	gtk_list_store_set(nodes_model, iter,
-		c_gnet_user_agent, n->vendor ? lazy_locale_to_utf8(n->vendor, 0) : NULL,
+		c_gnet_user_agent, n->vendor
+							? lazy_iso8859_1_to_utf8(n->vendor) : NULL,
 		c_gnet_loc, iso3166_country_cc(n->country),
 		c_gnet_version, version,
 		c_gnet_info, nodes_gui_common_status_str(&status),
@@ -342,7 +352,7 @@ update_tooltip(GtkTreeView *tv, GtkTreePath *path)
 			iso3166_country_name(info.country),
 			iso3166_country_cc(info.country),
 			_("Vendor:"),
-			info.vendor ? lazy_locale_to_utf8(info.vendor, 0) : _("Unknown"));
+			info.vendor ? lazy_iso8859_1_to_utf8(info.vendor) : _("Unknown"));
 
 		guc_node_clear_info(&info);
 		gtk_tooltips_set_tip(settings_gui_tooltips(),
@@ -392,7 +402,7 @@ host_lookup_callback(const gchar *hostname, gpointer data)
 
 	if (hostname) {
 		gm_snprintf(buf, sizeof buf, "%s (%s)",
-			lazy_locale_to_utf8(hostname, 0), ip_port_to_gchar(ip, port));
+			lazy_locale_to_utf8(hostname), ip_port_to_gchar(ip, port));
 	} else {
 		statusbar_gui_warning(10,
 			_("Reverse lookup for %s failed"), ip_to_gchar(ip));
@@ -545,7 +555,8 @@ nodes_gui_add_node(gnet_node_info_t *n)
     gtk_list_store_set(nodes_model, iter,
         c_gnet_host,    ip_port_to_gchar(n->ip, n->port),
         c_gnet_flags,    NULL,
-        c_gnet_user_agent, n->vendor ? lazy_locale_to_utf8(n->vendor, 0) : NULL,
+        c_gnet_user_agent, n->vendor
+							? lazy_iso8859_1_to_utf8(n->vendor) : NULL,
         c_gnet_loc, 	iso3166_country_cc(n->country),
         c_gnet_version, proto_tmp,
         c_gnet_connected, NULL,
@@ -609,9 +620,9 @@ update_row(gpointer key, gpointer value, gpointer user_data)
 
 /**
  * Update all the nodes at the same time.
- */
-
-/* FIXME: we should remember for every node when it was last
+ *
+ * @bug
+ * FIXME: we should remember for every node when it was last
  *       updated and only refresh every node at most once every
  *       second. This information should be kept in a struct pointed
  *       to by the row user_data and should be automatically freed
