@@ -1,5 +1,5 @@
 /*
- * $Id: search.c,v 1.42 2005/05/04 01:29:25 cbiere Exp $
+ * $Id: search.c,v 1.46 2005/07/26 21:20:16 cbiere Exp $
  *
  * Copyright (c) 2001-2003, Raphael Manfredi, Richard Eckart
  *
@@ -24,10 +24,14 @@
  */
 
 /**
+ * @ingroup gtk
  * @file
  *
  * GUI filtering functions.
  *
+ * @author Raphael Manfredi
+ * @author Richard Eckart
+ * @date 2001-2003
  */
 
 #include "gtk/gui.h"
@@ -54,13 +58,13 @@
 #include "lib/utf8.h"
 #include "lib/override.h"		/* Must be the last header included */
 
-RCSID("$Id: search.c,v 1.42 2005/05/04 01:29:25 cbiere Exp $");
+RCSID("$Id: search.c,v 1.46 2005/07/26 21:20:16 cbiere Exp $");
 
-#define MAX_TAG_SHOWN	60		/* Show only first chars of tag */
+#define MAX_TAG_SHOWN	60		/**< Show only first chars of tag */
 
 static gchar tmpstr[4096];
 
-static GList *searches = NULL;		/* List of search structs */
+static GList *searches = NULL;	/**< List of search structs */
 
 static GtkTreeView *tree_view_search = NULL;
 static GtkNotebook *notebook_search_results = NULL;
@@ -69,8 +73,8 @@ static GtkButton *button_search_clear = NULL;
 static GList *list_search_history = NULL;
 static gboolean search_gui_shutting_down = FALSE;
 
-/*
- * Private function prototypes
+/**
+ * Private function prototypes.
  */
 static GtkTreeViewColumn *add_column(GtkTreeView *treeview, const gchar *name,
 	gint id, gint width, gfloat xalign, gint fg_column, gint bg_column);
@@ -82,7 +86,7 @@ static GtkWidget *default_search_tree_view = NULL;
 GtkWidget *default_scrolled_window = NULL;
 
 
-/* For cyclic updates of the tooltip */
+/** For cyclic updates of the tooltip. */
 static tree_view_motion_t *tvm_search;
 
 /* ----------------------------------------- */
@@ -230,7 +234,7 @@ search_gui_clear_search(search_t *sch)
 	guc_search_update_items(sch->search_handle, sch->items);
 }
 
-/* *
+/**
  * Remove the search from the list of searches and free all
  * associated ressources (including filter and gui stuff).
  */
@@ -414,7 +418,9 @@ search_gui_new_search_full(const gchar *querystr, guint32 reissue_timeout,
 	return TRUE;
 }
 
-/* Searches results */
+/**
+ * Searches results.
+ */
 static gint
 search_gui_compare_size_func(
     GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data)
@@ -519,9 +525,9 @@ search_gui_add_record(
 		const gchar *s;
 
 		g_assert(rw < sizeof info);
-		s = lazy_locale_to_utf8(info, rw);
+		s = lazy_locale_to_utf8(info);
 		if (s != info) {
-			g_strlcpy(info, s, sizeof info);
+			utf8_strlcpy(info, s, sizeof info);
 		}
 	}
 
@@ -552,7 +558,7 @@ search_gui_add_record(
 
 	g_assert(rc->refcount >= 2);
 
-	name_utf8 = lazy_locale_to_utf8(rc->name, 0);
+	name_utf8 = lazy_locale_to_utf8(rc->name);
 	if (name_utf8) {
 		const gchar *p = strrchr(name_utf8, '.');
 
@@ -1360,8 +1366,9 @@ add_results_columns(GtkTreeView *treeview)
 	}
 }
 
-/* Create a new GtkTreeView for search results */
-
+/**
+ * Create a new GtkTreeView for search results.
+ */
 void
 gui_search_create_tree_view(GtkWidget ** sw, GtkWidget ** tv)
 {
@@ -1441,7 +1448,9 @@ tree_view_search_update(
 	return FALSE;
 }
 
-/* Like search_update_tab_label but always update the label */
+/**
+ * Like search_update_tab_label but always update the label.
+ */
 void
 gui_search_force_update_tab_label(search_t *sch, time_t now)
 {
@@ -1494,9 +1503,7 @@ gui_search_clear_results(void)
 	search_gui_update_items(search);
 }
 
-/*
- * gui_search_get_colors
- *
+/**
  * Extract the mark/ignore/download color.
  */
 void
@@ -1580,7 +1587,7 @@ gui_search_set_enabled(struct search *sch, gboolean enabled)
 
 
 /**
- *	Expand all nodes in tree for current search
+ * Expand all nodes in tree for current search.
  */
 void
 search_gui_expand_all(void)
@@ -1591,7 +1598,7 @@ search_gui_expand_all(void)
 
 
 /**
- *	Collapse all nodes in tree for current search
+ * Collapse all nodes in tree for current search.
  */
 void
 search_gui_collapse_all(void)
@@ -1629,9 +1636,7 @@ search_gui_end_massive_update(search_t *sch)
 }
 
 /**
- *
- * Update the search displays with the correct meta-data
- *
+ * Update the search displays with the correct meta-data.
  */
 void
 search_gui_metadata_update(const bitzi_data_t *data)
