@@ -1,7 +1,8 @@
 /*
- * $Id: upload_stats.c,v 1.7 2005/05/04 01:29:26 cbiere Exp $
+ * $Id: upload_stats.c,v 1.9 2005/06/29 14:24:29 daichik Exp $
  *
  * Copyright (c) 2001-2003, Raphael Manfredi
+ * Copyright (c) 2002, Michael Tesch
  *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
@@ -21,30 +22,41 @@
  *  Foundation, Inc.:
  *      59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *----------------------------------------------------------------------
+ */
+
+/**
+ * @ingroup gtk
+ * @file
  *
- * upload_stats.c - keep track of which files we send away, and how often.
+ * Keep track of which files we send away, and how often.
  *
- *		Statistics are kept by _FILENAME_ and file size,
- *		not by actual path, so two files with the same
- *		name and size will be counted in the same bin.
- *		I dont see this as a limitation because the
- *		user wouldn't be able to differentiate the files anyway.
- *		This could be extended to keep the entire path to
- *		each file and optionally show the entire path, but..
+ * Statistics are kept by _FILENAME_ and file size, not by actual
+ * path, so two files with the same name and size will be counted
+ * in the same bin.
  *
- *		the 'upload_history' file has the following format:
- *		<url-escaped filename> <file size> <attempts> <completions>
+ * I dont see this as a limitation because the user wouldn't be able
+ * to differentiate the files anyway. This could be extended to keep
+ * the entire path to each file and optionally show the entire path,
+ * but..
  *
- *		TODO: add a check to make sure that all of the files still exist(?)
- *			grey them out if they dont, optionally remove them from the
- *			stats list (when 'Clear Non-existent Files' is clicked)
+ * The 'upload_history' file has the following format:
  *
- *		(C) 2002 Michael Tesch, released with gtk-gnutella & its license
+ *		- "<url-escaped filename> <file size> <attempts> <completions>"
+ *
+ * @todo
+ * TODO: Add a check to make sure that all of the files still exist(?)
+ *       grey them out if they dont, optionally remove them from the
+ *       stats list (when 'Clear Non-existent Files' is clicked).
+ *
+ * @author Raphael Manfredi
+ * @date 2001-2003
+ * @author Michael Tesch
+ * @date 2002
  */
 
 #include "gtk/gui.h"
 
-RCSID("$Id: upload_stats.c,v 1.7 2005/05/04 01:29:26 cbiere Exp $");
+RCSID("$Id: upload_stats.c,v 1.9 2005/06/29 14:24:29 daichik Exp $");
 
 #include "interface-glade.h" /* for create_popup_upload_stats */
 
@@ -62,8 +74,9 @@ RCSID("$Id: upload_stats.c,v 1.7 2005/05/04 01:29:26 cbiere Exp $");
 static GtkTreeView *upload_stats_treeview = NULL;
 static GtkWidget *popup_upload_stats = NULL;
 
-/* Private callbacks */
-
+/**
+ * Private callbacks
+ */
 static gboolean
 on_button_press_event(GtkWidget *unused_widget, GdkEventButton *event,
 	gpointer unused_udata)
