@@ -1,5 +1,5 @@
 /*
- * $Id: uploads.c,v 1.16 2005/05/04 01:29:26 cbiere Exp $
+ * $Id: uploads.c,v 1.18 2005/07/26 21:20:17 cbiere Exp $
  *
  * Copyright (c) 2001-2003, Richard Eckart
  *
@@ -23,6 +23,16 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup gtk
+ * @file
+ *
+ * Needs short description here.
+ *
+ * @author Richard Eckart
+ * @date 2001-2003
+ */
+
 #include "gtk/gui.h"
 
 #include "interface-glade.h"
@@ -46,9 +56,9 @@
 #include "lib/walloc.h"
 #include "lib/override.h"		/* Must be the last header included */
 
-RCSID("$Id: uploads.c,v 1.16 2005/05/04 01:29:26 cbiere Exp $");
+RCSID("$Id: uploads.c,v 1.18 2005/07/26 21:20:17 cbiere Exp $");
 
-#define UPDATE_MIN	300		/* Update screen every 5 minutes at least */
+#define UPDATE_MIN	300		/**< Update screen every 5 minutes at least */
 
 static gboolean uploads_remove_lock = FALSE;
 static gboolean uploads_shutting_down = FALSE;
@@ -57,9 +67,9 @@ static GtkTreeView *treeview_uploads = NULL;
 static GtkListStore *store_uploads = NULL;
 static GtkWidget *button_uploads_clear_completed = NULL;
 
-/* hash table for fast handle -> GtkTreeIter mapping */
+/** hash table for fast handle -> GtkTreeIter mapping */
 static GHashTable *upload_handles = NULL;
-/* list of all *removed* uploads; contains the handles */
+/** list of all *removed* uploads; contains the handles */
 static GSList *sl_removed_uploads = NULL;
 
 static void uploads_gui_update_upload_info(const gnet_upload_info_t *u);
@@ -77,11 +87,11 @@ static const char * const column_titles[UPLOADS_GUI_VISIBLE_COLUMNS] = {
 };
 
 typedef struct remove_row_ctx {
-	gboolean force;			/* If false, rows will only be removed, if
-							 * their `entry_removal_timeout' has expired. */
-	time_t now; 			/* Current time, used to decide whether row
-							 * should be finally removed. */
-	GSList *sl_remaining;	/* Contains row data for not yet removed rows. */
+	gboolean force;			/**< If false, rows will only be removed, if
+							 **  their `entry_removal_timeout' has expired. */
+	time_t now; 			/**< Current time, used to decide whether row
+							 **  should be finally removed. */
+	GSList *sl_remaining;	/**< Contains row data for not yet removed rows. */
 } remove_row_ctx_t;
 
 
@@ -289,7 +299,7 @@ uploads_gui_update_upload_info(const gnet_upload_info_t *u)
 			atom_str_free(rd->name);
 		rd->name = atom_str_get(u->name);
 		gtk_list_store_set(store_uploads, &rd->iter,
-			c_ul_filename, lazy_locale_to_utf8(rd->name, 0),
+			c_ul_filename, lazy_locale_to_utf8(rd->name),
 			(-1));
 	}
 
@@ -300,7 +310,7 @@ uploads_gui_update_upload_info(const gnet_upload_info_t *u)
 			atom_str_free(rd->user_agent);
 		rd->user_agent = atom_str_get(u->user_agent);
 		gtk_list_store_set(store_uploads, &rd->iter,
-			c_ul_agent, lazy_locale_to_utf8(rd->user_agent, 0),
+			c_ul_agent, lazy_iso8859_1_to_utf8(rd->user_agent),
 			(-1));
 	}
 
@@ -385,7 +395,7 @@ uploads_gui_add_upload(gnet_upload_info_t *u)
 		static gchar str[256];	/* MUST be static! */
 		const gchar *agent;
 
-		agent = lazy_locale_to_utf8(u->user_agent, 0);
+		agent = lazy_iso8859_1_to_utf8(u->user_agent);
 		if (u->user_agent != agent) {
 			utf8_strlcpy(str, agent, sizeof str);
 			agent = str;
@@ -397,7 +407,7 @@ uploads_gui_add_upload(gnet_upload_info_t *u)
 	titles[c_ul_loc] = iso3166_country_cc(u->country);
 
 	titles[c_ul_filename] = NULL != u->name
-								? lazy_locale_to_utf8(u->name, 0) : "...";
+								? lazy_locale_to_utf8(u->name) : "...";
 	titles[c_ul_host]     = ip_to_gchar(u->ip);
 	titles[c_ul_status] = uploads_gui_status_str(&status, rd);
 
