@@ -1,10 +1,8 @@
 /*
- * $Id: nodes_common.c,v 1.11 2005/04/21 16:22:13 cbiere Exp $
+ * $Id: nodes_common.c,v 1.13 2005/06/29 14:24:28 daichik Exp $
  *
  * Copyright (c) 2001-2003, Raphael Manfredi, Richard Eckart
  *
- * Common GUI functions for displaying node information.
- *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
  *
@@ -25,9 +23,20 @@
  *----------------------------------------------------------------------
  */
 
+/**
+ * @ingroup gtk
+ * @file
+ *
+ * Common GUI functions for displaying node information.
+ *
+ * @author Raphael Manfredi
+ * @author Richard Eckart
+ * @date 2001-2003
+ */
+
 #include "gui.h"
 
-RCSID("$Id: nodes_common.c,v 1.11 2005/04/21 16:22:13 cbiere Exp $");
+RCSID("$Id: nodes_common.c,v 1.13 2005/06/29 14:24:28 daichik Exp $");
 
 #include "nodes_common.h"
 
@@ -293,25 +302,25 @@ nodes_gui_common_status_str(const gnet_node_status_t *n)
 	return a;
 }
 
-/*
- * nodes_gui_common_flags_str
+/**
+ * Display a summary of the node flags.
  *
- * Display a summary of the node flags:
+ * The stuff in the Flags column means:
  *
- *    012345678AB (offset)
- *    NIrwqxZPFhT
- *    ^^^^^^^^^^^
- *    ||||||||||+ T indicates a TLS-tunneled connection
- *    |||||||||+  hops flow triggerd (h), or total query flow control (f)
- *    ||||||||+   flow control (F), or pending data in queue (d)
- *    |||||||+    indicates whether we're a push proxy (P) / node is proxy (p)
- *    ||||||+     indicates whether Rx, Tx or both (Z) are compressed
- *    |||||+      indicates whether we sent our last-hop QRT to remote UP
- *    ||||+       indicates whether we sent/received a QRT, or send/receive one
- *    |||+        indicates whether node is writable
- *    ||+         indicates whether node is readable
- *    |+          indicates connection type (Incoming, Outgoing, Ponging)
- *    +           indicates peer mode (Normal, Ultra, Leaf)
+ *  - 012345678AB (offset)
+ *  - NIrwqxZPFhT
+ *  - ^^^^^^^^^^^
+ *  - ||||||||||+ T indicates a TLS-tunneled connection
+ *  - |||||||||+  hops flow triggerd (h), or total query flow control (f)
+ *  - ||||||||+   flow control (F), or pending data in queue (d)
+ *  - |||||||+    indicates whether we're a push proxy (P) / node is proxy (p)
+ *  - ||||||+     indicates whether RX, TX or both (Z) are compressed
+ *  - |||||+      indicates whether we sent our last-hop QRT to remote UP
+ *  - ||||+       indicates whether we sent/received a QRT, or send/receive one
+ *  - |||+        indicates whether node is writable
+ *  - ||+         indicates whether node is readable
+ *  - |+          indicates connection type (Incoming, Outgoing, Ponging)
+ *  - +           indicates peer mode (Normal, Ultra, Leaf)
  */
 const gchar *
 nodes_gui_common_flags_str(const gnet_node_flags_t *flags)
