@@ -1,5 +1,5 @@
 /*
- * $Id: uploads_common.c,v 1.14 2005/01/23 21:54:10 cbiere Exp $
+ * $Id: uploads_common.c,v 1.16 2005/07/01 09:28:06 daichik Exp $
  *
  * Copyright (c) 2001-2003, Richard Eckart
  *
@@ -25,7 +25,7 @@
 
 #include "gui.h"
 
-RCSID("$Id: uploads_common.c,v 1.14 2005/01/23 21:54:10 cbiere Exp $");
+RCSID("$Id: uploads_common.c,v 1.16 2005/07/01 09:28:06 daichik Exp $");
 
 #include "uploads.h"			/* For upload_row_data_t */
 #include "uploads_common.h"
@@ -37,12 +37,12 @@ RCSID("$Id: uploads_common.c,v 1.14 2005/01/23 21:54:10 cbiere Exp $");
 #include "lib/glib-missing.h"	/* For gm_snprintf() */
 #include "lib/override.h"		/* Must be the last header included */
 
-#define IO_STALLED		60		/* If nothing exchanged after that many secs */
+#define IO_STALLED		60		/**< If nothing exchanged after that many secs */
 
-/*
+/**
  * uploads_gui_progress
  *
- * Returns a floating point value from [0:1] which indicates
+ * @returns a floating point value from [0:1] which indicates
  * the total progress of the upload.
  */
 gfloat uploads_gui_progress(
@@ -167,7 +167,7 @@ uploads_gui_status_str(const gnet_upload_status_t *u,
 			queued = u->parq_position > max_up - cur_up;
 				
 			slen += gm_snprintf(tmpstr, sizeof(tmpstr),
-						_("%s [%d] (slot %d / %d)"),
+						_("%s [%d] (slot %d/%d)"),
 						queued ? _("Queued") : _("Waiting"),
 						u->parq_queue_no,
 						u->parq_position,
