@@ -1,9 +1,7 @@
 /*
- * $Id: visual_progress.c,v 1.31 2005/04/27 15:36:20 cbiere Exp $
+ * $Id: visual_progress.c,v 1.35 2005/06/29 14:24:28 daichik Exp $
  *
- * Copyright (c) 2003-2004, Hans de Graaff
- *
- * Displaying the visual progress of downloading graphically.
+ * Copyright (c) 2003-2005, Hans de Graaff
  *
  *----------------------------------------------------------------------
  * This file is part of gtk-gnutella.
@@ -26,26 +24,27 @@
  */
 
 /**
+ * @ingroup gtk
  * @file
  *
+ * Displaying the visual progress of downloading graphically.
+ *
  * Visual progress indicator for files in the download queue.
  *
- * TODO and other ideas to be implemented.
- *
- * make colors into properties so that they can be stored in config,
- * should keep hardcoded backups.
- *
- * Add progress data also to fileinfo table, so that the info is shown for
- * all current files.
- *
- * Do not redraw the bar too often, only on event for actual file and
- * perhaps max once a second.
+ * @todo Make colors into properties so that they can be stored in config,
+ *       should keep hardcoded backups.
+ * @todo Add progress data also to fileinfo table, so that the info is shown 
+ *       for all current files.
+ * @todo Do not redraw the bar too often, only on event for actual file and
+ *       perhaps max once a second.
  *
+ * @author Hans de Graaff
+ * @date 2003-2005
  */
 
 #include "gui.h"
 
-RCSID("$Id: visual_progress.c,v 1.31 2005/04/27 15:36:20 cbiere Exp $");
+RCSID("$Id: visual_progress.c,v 1.35 2005/06/29 14:24:28 daichik Exp $");
 
 #include "visual_progress.h"
 
@@ -56,22 +55,22 @@ RCSID("$Id: visual_progress.c,v 1.31 2005/04/27 15:36:20 cbiere Exp $");
 #include "lib/walloc.h"
 #include "lib/override.h"	/* Must be the last header included */
 
-/* The height of the indicator arrows in visual progress */
+/** The height of the indicator arrows in visual progress */
 #define VP_ARROW_HEIGHT 7 
 
 /**
- * The context for drawing, including location to draw
+ * The context for drawing, including location to draw.
  */
 typedef struct vp_context {
-	GtkWidget *widget;     /** The widget containing the drawing area */
-    GdkDrawable *drawable; /** The drawable inside the widget */
-    GdkGC *gc;             /** The Graphics Context used in this vp context */
-    gnet_fi_t fih;         /** The most recently used fileinfo handle */
-	gboolean fih_valid;    /** Whether fih is still a valid handle */
+	GtkWidget *widget;      /**< The widget containing the drawing area */
+    GdkDrawable *drawable;  /**< The drawable inside the widget */
+    GdkGC *gc;              /**< The Graphics Context used in this vp context */
+    gnet_fi_t fih;          /**< The most recently used fileinfo handle */
+	gboolean fih_valid;	    /**< Whether fih is still a valid handle */
 } vp_context_t;
 
 /**
- * Locally cached information from fileinfo needed for drawing the graphics
+ * Locally cached information from fileinfo needed for drawing the graphics.
  */
 typedef struct vp_info {
     gnet_fi_t fi_handle;
@@ -84,29 +83,29 @@ typedef struct vp_info {
     vp_context_t *context;
 } vp_info_t;
 
-static GHashTable *vp_info_hash; /* Hash table with our cached fileinfo info */
+static GHashTable *vp_info_hash; /**< Hash table with our cached fileinfo info */
 
-static GdkColor done;       /* Pre-filled color (green) for DONE chunks */
-static GdkColor done_old;	/* Pre-filled color (dull green) for DONE
-							 * chunks from previous sessions */
-static GdkColor busy;       /* Pre-filled color (yellow) for BUSY chunks */
-static GdkColor arrow;      /* Pre-filled color (blue) for start of BUSY */
-static GdkColor empty;      /* Pre-filled color (red) for EMPTY chunks */
-static GdkColor black;      /* Pre-filled color (black) for general drawing */
-static GdkColor available;  /* Pre-filled color (blue) available on network */
-static GdkColor nosize;     /* Pre-filled color (gray) indicates
+static GdkColor done;       /**< Pre-filled color (green) for DONE chunks */
+static GdkColor done_old;	/**< Pre-filled color (dull green) for DONE
+								 chunks from previous sessions */
+static GdkColor busy;       /**< Pre-filled color (yellow) for BUSY chunks */
+static GdkColor arrow;      /**< Pre-filled color (blue) for start of BUSY */
+static GdkColor empty;      /**< Pre-filled color (red) for EMPTY chunks */
+static GdkColor black;      /**< Pre-filled color (black) for general drawing */
+static GdkColor available;  /**< Pre-filled color (blue) available on network */
+static GdkColor nosize;     /**< Pre-filled color (gray) indicates
 								 chunk information is not available
 								 (e.g. file size == 0 */
-static GdkColor *base;      /* Theme-defined background color */
+static GdkColor *base;      /**< Theme-defined background color */
 
 /**
- * The visual progress context for drawing fileinfo information
+ * The visual progress context for drawing fileinfo information.
  */
 static vp_context_t fi_context;
 
 
 /**
- * Draw a rectangle for visual progress
+ * Draw a rectangle for visual progress.
  */
 void
 vp_draw_rectangle(vp_info_t *v, filesize_t from, filesize_t to,
@@ -141,7 +140,7 @@ vp_draw_rectangle(vp_info_t *v, filesize_t from, filesize_t to,
 }
 
 /**
- * Draw a chunk for visual progress
+ * Draw a chunk for visual progress.
  */
 void
 vp_draw_chunk (gpointer data, gpointer user_data)
@@ -166,7 +165,7 @@ vp_draw_chunk (gpointer data, gpointer user_data)
 }
 
 /**
- * Draw an downward arrow starting at the top
+ * Draw an downward arrow starting at the top.
  */
 void
 vp_draw_arrow(vp_info_t *v, filesize_t at)
@@ -286,7 +285,7 @@ vp_draw_fi_progress(gboolean valid, gnet_fi_t fih)
 }
 
 /**
- * Callback for the fileinfo pane GtkDrawingArea
+ * Callback for the fileinfo pane GtkDrawingArea.
  */
 void
 on_drawingarea_fi_progress_realize(GtkWidget *widget, gpointer user_data)
@@ -305,7 +304,7 @@ on_drawingarea_fi_progress_realize(GtkWidget *widget, gpointer user_data)
 }
 
 /**
- * Callback for the fileinfo pane GtkDrawingArea
+ * Callback for the fileinfo pane GtkDrawingArea.
  */
 gboolean
 on_drawingarea_fi_progress_expose_event(
@@ -384,7 +383,7 @@ vp_gui_fi_added(gnet_fi_t fih)
 }
 
 /**
- * Handle the event that a fileinfo entry has been removed
+ * Handle the event that a fileinfo entry has been removed.
  *
  * @param fih The fileinfo handle of the entry to be removed
  */
@@ -430,7 +429,7 @@ vp_print_chunk(gnet_fi_chunks_t *c, gboolean show_old)
 			(gint) c->status);
 }
 
-/*
+/**
  * For debugging: print chunk list.
  */
 static void
@@ -740,7 +739,7 @@ vp_gui_fi_ranges_changed(gnet_fi_t fih)
 
 
 /**
- * Free the vp_info_t structs in the vp_info_hash
+ * Free the vp_info_t structs in the vp_info_hash.
  */
 void
 vp_free_key_value (gpointer key, gpointer value, gpointer user_data)
@@ -756,7 +755,7 @@ vp_free_key_value (gpointer key, gpointer value, gpointer user_data)
 
 /**
  * Initialize the use of visual progress.
-
+ *
  * Register listeners into the fileinfo structure so that we are
  * notified of fileinfo events, and get a permanent handle to the
  * drawing area for later reuse.
@@ -805,7 +804,7 @@ vp_gui_init(void)
 }
 
 /**
- * Undo everything set up in vp_gui_init
+ * Undo everything set up in vp_gui_init.
  */
 void
 vp_gui_shutdown(void)
